<?xml version='1.0' encoding='UTF-8'?>
<!-- eIzidor                                                                          -->
<!-- Digital text-critical editions of Slovene literature           -->
<!-- ZRC SAZU, IJS                                                  -->
<!--                                                                -->
<!-- Stylesheet for conversion of TEI eIzidor to HTML            -->
<!--                                                                -->
<!-- Toma&zcaron; Erjavec,                                          -->
<!-- 2007-10-01                                                    -->

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl="http://exslt.org/common" exclude-result-prefixes="exsl"
  extension-element-prefixes="exsl" version="1.1">

  <!--xsl:import href="hdr2html.xsl"/-->

  <xsl:param name="outName">spoti</xsl:param>
  <xsl:param name="outDir"/>
  <xsl:param name="split"/>
  <xsl:param name="debug"/>
  <xsl:param name="verbose">yes</xsl:param>

  <xsl:param name="outFile" select="concat($outName,'.html')"/>

  <xsl:param name="homeURL" select="$outFile"/>
  <xsl:param name="teiHeader-sl" select="concat($outName,'.teiHeader','-sl','.html')"/>
  <xsl:param name="teiHeader-desc-sl">Kolofon TEI</xsl:param>
  <xsl:variable name="id"/>

  <xsl:variable name="css_style">
    <xsl:text>
     body { color: #000000; background-color: #FFFFCC; font-family: "Times New Roman", "Times"; } 
     .normal { font-family: Times; }
      a:link {color:#B22222}    
      a:hover{color:#D2691E}   
      a:visited {color:#663333}   
      /* a:visited { color: #000077;} */ 
      span.meta {font-family: Arial, Verdana; font-size: smaller; color: #696969;} 
      span.parnum {font-family: Arial, Verdana; font-size:70%; color: #696969; padding-right: 0.5em; } 
      span.divnum {color: #696969; padding-right: 0.5em;}
      .break    { margin-top: 3px; margin-bottom: 3px} 
      .center { text-align: center; } 
      .right {text-align: right; } 
     .justify { text-align: justify; } 
    </xsl:text>
    <!--xsl:for-each select="//witList/witness">
      <xsl:value-of select="@rend"/>
      </xsl:for-each-->
    <xsl:text>
      span.DS {color: red}
      span.KN {color: green}
    </xsl:text>
  </xsl:variable>

  <xsl:param name="def-title">
    <A href="{concat($outName,'.html')}">
    <xsl:text>Izidor Cankar, S POTI</xsl:text>
    </A>
  </xsl:param>

  <xsl:variable name="html-footer1">
    <hr/>
    <SMALL> Avtorske pravice za to izdajo ureja licenca <!-- Uredni bljah: To delo je licencirano <sic>z</sic> -->
      <a rel="license" href="http://creativecommons.org/licenses/by-sa/2.5/si/">Creative Commons
        Priznanje avtorstva-Deljenje pod enakimi pogoji 2.5 Slovenija</a>
      <br/>Projekt <A HREF="http://nl.ijs.si/e-zrc/">Elektronske znanstvenokriti&#x10D;ne izdaje
        slovenskega slovstva</A>
      <BR/> Datoteka HTML narejena s pretvorbo XSLT baze XML/<A HREF="http://www.tei-c.org/P4X/">TEI
        P4</A>. </SMALL>
  </xsl:variable>
  <xsl:variable name="html-footer2">
    <SMALL>
      <BR/>
      <A HREF="http://validator.w3.org/check?uri=referer">
        <IMG border="0" src="http://www.w3.org/Icons/valid-html401" alt="Valid HTML 4.01!"
          height="31" width="88"/>
      </A>
      <A HREF="http://jigsaw.w3.org/css-validator/">
        <IMG border="0" src="http://www.w3.org/Icons/valid-css" alt="Valid CSS!" height="31"
          width="88"/>
      </A>
      <xsl:comment>Creative Commons License</xsl:comment>
      <a rel="license" href="http://creativecommons.org/licenses/by-sa/2.5/si/">
        <img alt="Creative Commons License" style="border-width: 0"
          src="http://i.creativecommons.org/l/by-sa/2.5/si/88x31.png"/>
      </a>
      <xsl:comment>/Creative Commons License</xsl:comment>
      <xsl:comment>
        <!--rdf:RDF xmlns="http://web.resource.org/cc/" xmlns:dc="http://purl.org/dc/elements/1.1/"
          xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
          xmlns:rdfs="http://www.w3.org/2000/01/rdf-schema#">
          <Work rdf:about="">
            <license rdf:resource="http://creativecommons.org/licenses/by-sa/2.5/si/"/>
          </Work>
          <License rdf:about="http://creativecommons.org/licenses/by-sa/2.5/si/">
            <permits rdf:resource="http://web.resource.org/cc/Reproduction"/>
            <permits rdf:resource="http://web.resource.org/cc/Distribution"/>
            <requires rdf:resource="http://web.resource.org/cc/Notice"/>
            <requires rdf:resource="http://web.resource.org/cc/Attribution"/>
            <permits rdf:resource="http://web.resource.org/cc/DerivativeWorks"/>
            <requires rdf:resource="http://web.resource.org/cc/ShareAlike"/>
          </License>
        </rdf:RDF-->
      </xsl:comment>
    </SMALL>
  </xsl:variable>

  <xsl:output method="html" encoding="utf-8" indent="yes"/>

  <xsl:strip-space elements="div"/>
  <xsl:preserve-space elements="head p note hi add del corr"/>

  <xsl:template match="/">
    <xsl:choose>
      <xsl:when test="$split">
        <xsl:call-template name="outputChunk">
          <xsl:with-param name="outFile" select="$teiHeader-sl"/>
          <xsl:with-param name="title" select="concat($def-title,': ','teiHeader')"/>
          <xsl:with-param name="content">
            <xsl:apply-templates select="TEI.2/teiHeader"/>
          </xsl:with-param>
        </xsl:call-template>
        <xsl:apply-templates select="TEI.2/text"/>
      </xsl:when>
      <xsl:otherwise>
        <HTML>
          <HEAD>
            <TITLE>
              <xsl:value-of select="normalize-space($def-title)"/>
            </TITLE>
            <META http-equiv="Content-Type" content="text/html; charset=utf-8"/>
            <STYLE TYPE="text/css">
              <xsl:value-of select="$css_style"/>
            </STYLE>
          </HEAD>
          <BODY>
            <xsl:call-template name="chunk"/>
          </BODY>
        </HTML>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="text">
    <xsl:variable name="title">
      <xsl:choose>
        <xsl:when test="//teiHeader">
          <xsl:value-of select="//fileDesc/titleStmt/title"/>
          <xsl:text> (</xsl:text>
          <xsl:value-of select="//teiHeader/@date.updated"/>
          <xsl:text>)</xsl:text>
        </xsl:when>
        <xsl:otherwise>
          <xsl:copy-of select="$def-title"/>
          <xsl:text/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <xsl:variable name="head">
      <xsl:choose>
        <xsl:when test="//teiHeader">
          <H1 align="center">
            <xsl:value-of select="$title"/>
          </H1>
          <xsl:for-each select="//fileDesc/titleStmt/author">
            <H2>
              <xsl:value-of select="."/>
            </H2>
          </xsl:for-each>
          <H2>Izdaja <xsl:value-of select="//editionStmt/edition"/></H2>
          <xsl:for-each select="//fileDesc/titleStmt/respStmt">
            <H3>
              <xsl:value-of select="resp"/>
              <xsl:text> </xsl:text>
              <xsl:value-of select="name"/>
            </H3>
          </xsl:for-each>
        </xsl:when>
        <xsl:otherwise>
          <H1 align="center">
            <xsl:copy-of select="$def-title"/>
          </H1>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <xsl:choose>
      <xsl:when test="$split">
        <xsl:call-template name="outputChunk">
          <xsl:with-param name="outFile" select="$outFile"/>
          <xsl:with-param name="title" select="$def-title"/>
          <xsl:with-param name="content">
            <!--xsl:copy-of select="$head"/-->
            <xsl:apply-templates select="front"/>
            <xsl:call-template name="toc-main"/>
            <xsl:apply-templates select="body"/>
            <xsl:apply-templates select="back"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
        <xsl:call-template name="chunk"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="div">
    <xsl:param name="wit"/>
    <xsl:call-template name="anchor"/>
    <xsl:if test="ancestor::back and @type='section'">
      <HR/>
    </xsl:if>
    <xsl:apply-templates>
      <xsl:with-param name="wit" select="$wit"/>
    </xsl:apply-templates>
  </xsl:template>

  <xsl:template match="div[@type='part']">
    <xsl:variable name="wit">
      <xsl:if test="divGen">
        <xsl:value-of select="divGen/@type"/>
      </xsl:if>
    </xsl:variable>
    <xsl:choose>
      <xsl:when test="$split">
        <xsl:call-template name="outputChunk">
          <xsl:with-param name="outFile">
            <xsl:choose>
              <xsl:when test="ancestor::body">
                <xsl:value-of select="concat($outName,'-',@id,'.html')"/>
              </xsl:when>
              <xsl:when test="ancestor::back">
                <xsl:value-of select="concat($outName,'-','back','.html')"/>
              </xsl:when>
            </xsl:choose>
          </xsl:with-param>
          <xsl:with-param name="title">
            <xsl:value-of select="concat(normalize-space($def-title),': ',.//head[1])"/>
          </xsl:with-param>
          <xsl:with-param name="content">
            <xsl:call-template name="chunk">
              <xsl:with-param name="wit" select="$wit"/>
              <xsl:with-param name="suffix">
                <xsl:choose>
                  <xsl:when test="ancestor::body">
                    <xsl:value-of select="@id"/>
                  </xsl:when>
                  <xsl:when test="ancestor::back">back</xsl:when>
                </xsl:choose>
              </xsl:with-param>
            </xsl:call-template>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-templates>
          <xsl:with-param name="wit" select="$wit"/>
        </xsl:apply-templates>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="divGen">
    <xsl:apply-templates select="id(@corresp)">
      <xsl:with-param name="wit" select="@type"/>
    </xsl:apply-templates>
  </xsl:template>

  <xsl:template match="front">
    <xsl:if test="not($split)">
      <HR/>
    </xsl:if>
    <xsl:apply-templates/>
    <HR/>
  </xsl:template>

  <xsl:template match="body">
    <xsl:apply-templates/>
  </xsl:template>

  <xsl:template match="back">
    <xsl:apply-templates/>
  </xsl:template>

  <xsl:template mode="toc" match="back">
    <xsl:apply-templates mode="toc" select="div">
      <xsl:with-param name="level">2</xsl:with-param>
      <xsl:with-param name="suffix">back</xsl:with-param>
    </xsl:apply-templates>
  </xsl:template>

  <xsl:template mode="toc" match="div">
    <xsl:param name="level">5</xsl:param>
    <xsl:param name="wit"/>
    <xsl:param name="suffix">
      <xsl:choose>
        <xsl:when test="ancestor::back">back</xsl:when>
        <xsl:when test="ancestor-or-self::div[@type='part']">
          <xsl:value-of select="ancestor-or-self::div[@type='part']/@id"/>
        </xsl:when>
      </xsl:choose>
    </xsl:param>
    <xsl:variable name="head">
      <xsl:if test="docAuthor">
        <xsl:value-of select="docAuthor"/>
        <xsl:text>: </xsl:text>
      </xsl:if>
      <xsl:apply-templates mode="toc" select="head">
        <xsl:with-param name="wit" select="$wit"/>
      </xsl:apply-templates>
    </xsl:variable>
    <xsl:variable name="href">
      <xsl:call-template name="href">
        <xsl:with-param name="suffix" select="$suffix"/>
      </xsl:call-template>
    </xsl:variable>
    <xsl:if test="$level">
      <xsl:choose>
        <xsl:when test="normalize-space($head)">
          <LI>
            <A href="{$href}">
              <xsl:copy-of select="$head"/>
            </A>
            <xsl:if test="div and $level &gt; 1">
              <UL>
                <xsl:apply-templates mode="toc" select="div | divGen">
                  <xsl:with-param name="level" select="$level - 1"/>
                  <xsl:with-param name="suffix" select="$suffix"/>
                  <xsl:with-param name="wit" select="$wit"/>
                </xsl:apply-templates>
              </UL>
            </xsl:if>
          </LI>
        </xsl:when>
        <!-- blind div -->
        <xsl:otherwise>
          <xsl:apply-templates mode="toc" select="div | divGen">
            <xsl:with-param name="level" select="$level - 1"/>
            <xsl:with-param name="suffix" select="$suffix"/>
            <xsl:with-param name="wit" select="$wit"/>
          </xsl:apply-templates>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:if>
  </xsl:template>

  <xsl:template mode="toc" match="divGen">
    <xsl:apply-templates mode="toc" select="id(@corresp)">
      <xsl:with-param name="level">4</xsl:with-param>
      <xsl:with-param name="wit" select="@type"/>
      <xsl:with-param name="suffix" select="@type"/>
    </xsl:apply-templates>
  </xsl:template>

  <xsl:template match="figure">
    <xsl:if test="parent::p">
      <xsl:text disable-output-escaping="yes">&lt;/p&gt;</xsl:text>
    </xsl:if>
    <xsl:call-template name="anchor"/>
    <TABLE summary="Slika: {figDesc}" align="center">
      <xsl:variable name="small" select="concat(substring-before(@url,'.jpg'),'-small.jpg')"/>
      <TR>
        <TD valign="top" align="center">
          <A href="{@url}">
            <IMG src="{$small}" alt="{figDesc}"/>
          </A>
        </TD>
      </TR>
      <TR>
        <TH align="center">
          <xsl:apply-templates select="figDesc"/>
        </TH>
      </TR>
    </TABLE>
    <xsl:if test="parent::p">
      <xsl:text disable-output-escaping="yes">&lt;p&gt;</xsl:text>
    </xsl:if>
  </xsl:template>

  <xsl:template match="p">
    <xsl:param name="wit"/>
    <P>
      <xsl:call-template name="align"/>
      <xsl:if test="not(normalize-space($wit)) and @n">
        <xsl:call-template name="anchor">
          <xsl:with-param name="id" select="@id"/>
        </xsl:call-template>
        <SPAN class="parnum">
          <xsl:text>&#xA7;</xsl:text>
          <A href="#{@id}">
            <xsl:value-of select="@n"/>
          </A>
        </SPAN>
      </xsl:if>
      <xsl:apply-templates>
        <xsl:with-param name="wit" select="$wit"/>
      </xsl:apply-templates>
    </P>
  </xsl:template>

  <xsl:template match="lg">
    <xsl:param name="wit"/>
    <xsl:param name="para"/>
    <xsl:apply-templates>
      <xsl:with-param name="wit" select="$wit"/>
      <xsl:with-param name="para">
        <xsl:value-of select="$para"/>
      </xsl:with-param>
    </xsl:apply-templates>
    <BR/>
  </xsl:template>

  <xsl:template match="l">
    <xsl:param name="wit"/>
    <xsl:param name="para"/>
    <P class="break">
      <xsl:call-template name="span-align"/>
      <xsl:apply-templates>
        <xsl:with-param name="wit" select="$wit"/>
        <xsl:with-param name="para">
          <xsl:value-of select="$para"/>
        </xsl:with-param>
      </xsl:apply-templates>
    </P>
  </xsl:template>

  <xsl:template match="table">
    <xsl:if test="parent::p">
      <xsl:text disable-output-escaping="yes">&lt;/p&gt;</xsl:text>
    </xsl:if>
    <TABLE border="border" rules="all" summary="tabela">
      <xsl:apply-templates/>
    </TABLE>
    <xsl:if test="parent::p">
      <xsl:text disable-output-escaping="yes">&lt;p&gt;</xsl:text>
    </xsl:if>
  </xsl:template>

  <xsl:template match="row">
    <TR>
      <xsl:apply-templates/>
    </TR>
  </xsl:template>

  <xsl:template match="cell">
    <TD>
      <xsl:apply-templates/>
    </TD>
  </xsl:template>

  <xsl:template match="head" mode="toc">
    <xsl:param name="wit"/>
    <xsl:if test="parent::div/@n">
      <SPAN class="divnum">
        <xsl:value-of select="parent::div/@n"/>
      </SPAN>
    </xsl:if>
    <xsl:apply-templates>
      <xsl:with-param name="wit" select="$wit"/>
    </xsl:apply-templates>
  </xsl:template>

  <xsl:template mode="toc" match="note"/>
  <xsl:template mode="toc" match="text()">
    <xsl:value-of select="."/>
  </xsl:template>
  <xsl:template mode="toc" match="*">
    <xsl:apply-templates select="."/>
  </xsl:template>

  <xsl:template match="head">
    <xsl:param name="wit"/>
    <xsl:param name="para"/>
    <xsl:choose>
      <xsl:when test="parent::front">
        <H1 align="center">
          <xsl:apply-templates/>
        </H1>
      </xsl:when>
      <xsl:when test="parent::body"/>
      <xsl:when test="../@type='section'">
        <H2>
          <xsl:if test="parent::div/@n">
            <SPAN class="divnum">
              <xsl:value-of select="parent::div/@n"/>
            </SPAN>
          </xsl:if>
          <xsl:apply-templates>
            <xsl:with-param name="wit" select="$wit"/>
          </xsl:apply-templates>
        </H2>
      </xsl:when>
      <xsl:when test="../@type='subsection'">
        <H2>
          <xsl:call-template name="align"/>
          <xsl:apply-templates/>
        </H2>
      </xsl:when>
      <xsl:when test="ancestor::div[4]">
        <H5>
          <xsl:call-template name="align"/>
          <xsl:apply-templates/>
        </H5>
      </xsl:when>
      <xsl:when test="ancestor::div[3]">
        <H4>
          <xsl:call-template name="align"/>
          <xsl:apply-templates/>
        </H4>
      </xsl:when>
      <xsl:when test="ancestor::div[2]">
        <H3>
          <xsl:call-template name="align"/>
          <xsl:apply-templates/>
        </H3>
      </xsl:when>
      <xsl:otherwise>
        <H2>
          <xsl:call-template name="align"/>
          <xsl:apply-templates/>
        </H2>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="list/head">
    <xsl:param name="wit"/>
    <H5>
      <xsl:call-template name="align"/>
      <xsl:apply-templates>
        <xsl:with-param name="wit" select="$wit"/>
      </xsl:apply-templates>
    </H5>
  </xsl:template>

  <xsl:template match="table/head">
    <CAPTION>
      <xsl:call-template name="align"/>
      <xsl:apply-templates/>
    </CAPTION>
  </xsl:template>

  <xsl:template match="text//note[@place='inline']">
    <BR/>
    <SMALL>
      <xsl:apply-templates/>
    </SMALL>
  </xsl:template>

  <xsl:template match="note">
    <xsl:param name="wit"/>
    <xsl:if test="not(normalize-space($wit))">
      <xsl:variable name="id">
        <xsl:choose>
          <xsl:when test="@id">
            <xsl:value-of select="@id"/>
          </xsl:when>
          <xsl:otherwise>
            <xsl:value-of select="generate-id(.)"/>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:variable>
      <xsl:call-template name="anchor">
        <xsl:with-param name="id" select="concat($id,@place)"/>
      </xsl:call-template>
      <SUP>
        <SPAN class="normal">
          <SMALL>
            <xsl:if test="preceding-sibling::*[1][name(note)]">
              <xsl:text>,</xsl:text>
            </xsl:if>
            <A href="#{$id}">
              <xsl:attribute name="title">
                <xsl:value-of select="normalize-space(.)"/>
              </xsl:attribute>
              <xsl:choose>
                <xsl:when test="@n">
                  <xsl:value-of select="@n"/>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:number level="any" count="note" from="div[@type='part']"/>
                </xsl:otherwise>
              </xsl:choose>
            </A>
          </SMALL>
        </SPAN>
      </SUP>
      <xsl:if test="not(preceding-sibling::*[1][name(note)])">
        <xsl:text> </xsl:text>
      </xsl:if>
    </xsl:if>
  </xsl:template>

  <xsl:template match="note" mode="show">
    <xsl:variable name="id">
      <xsl:choose>
        <xsl:when test="@id">
          <xsl:value-of select="@id"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="generate-id(.)"/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <LI>
      <xsl:call-template name="anchor"/>
      <xsl:apply-templates/>
      <A href="#{$id}{@place}">&#8594;</A>
    </LI>
  </xsl:template>

  <xsl:template match="titlePage">
    <xsl:apply-templates/>
    <HR/>
  </xsl:template>

  <xsl:template match="docTitle">
    <H1 align="center">
      <xsl:apply-templates/>
    </H1>
  </xsl:template>

  <xsl:template match="docTitle[titlePart]">
    <xsl:apply-templates/>
  </xsl:template>

  <xsl:template match="titlePart">
    <H1 align="center">
      <xsl:apply-templates/>
    </H1>
  </xsl:template>

  <xsl:template match="titlePart[@type='subtitle']">
    <H2 align="center">
      <xsl:apply-templates/>
    </H2>
  </xsl:template>

  <xsl:template match="docImprint">
    <H4 align="center">
      <xsl:apply-templates/>
    </H4>
  </xsl:template>

  <xsl:template match="docAuthor">
    <H1 align="center">
      <xsl:apply-templates/>
    </H1>
  </xsl:template>

  <xsl:template match="back//docAuthor">
    <H4>
      <xsl:apply-templates/>
    </H4>
  </xsl:template>

  <xsl:template match="byline/docAuthor">
    <xsl:apply-templates/>
  </xsl:template>
  <xsl:template match="byline">
    <H3 align="center">
      <xsl:apply-templates/>
    </H3>
  </xsl:template>

  <xsl:template match="text//name">
    <xsl:choose>
      <xsl:when test="$debug">
        <FONT color="purple">
          <xsl:apply-templates/>
        </FONT>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-templates/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="signed | dateline">
    <xsl:param name="wit"/>
    <P class="right">
      <!--xsl:call-template name="align"/-->
      <xsl:apply-templates>
        <xsl:with-param name="wit" select="$wit"/>
      </xsl:apply-templates>
    </P>
  </xsl:template>

  <xsl:template match="text//date">
    <xsl:choose>
      <xsl:when test="$debug">
        <FONT color="violet">
          <xsl:apply-templates/>
        </FONT>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-templates/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="foreign">
    <xsl:choose>
      <xsl:when test="$debug">
        <FONT color="fuchsia">
          <xsl:apply-templates/>
        </FONT>
      </xsl:when>
      <xsl:otherwise>
        <I>
          <xsl:apply-templates/>
        </I>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="sic">
    <FONT color="red">
      <xsl:apply-templates/>
    </FONT>
  </xsl:template>

  <xsl:template name="align">
    <xsl:if test="@rend = 'right' or @rend = 'center' or @rend = 'justify'">
      <xsl:attribute name="align">
        <xsl:value-of select="@rend"/>
      </xsl:attribute>
    </xsl:if>
  </xsl:template>

  <xsl:template name="span-align">
    <xsl:if test="@rend = 'right' or @rend = 'center' or @rend = 'justify'">
      <xsl:attribute name="style">
        <xsl:text>text-align: </xsl:text>
        <xsl:value-of select="@rend"/>
        <xsl:text>;</xsl:text>
      </xsl:attribute>
    </xsl:if>
  </xsl:template>

  <xsl:template name="rend">
    <xsl:param name="rend" select="@rend"/>
    <xsl:variable name="rest" select="substring-after($rend,' ')"/>
    <xsl:variable name="first">
      <xsl:choose>
        <xsl:when test="$rest">
          <xsl:value-of select="substring-before($rend,' ')"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:variable name="first" select="$rend"/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <xsl:if test="$first">
      <xsl:choose>
        <xsl:when test="$first = 'bold'">
          <B>
            <xsl:call-template name="rend">
              <xsl:with-param name="rend" select="$rest"/>
            </xsl:call-template>
          </B>
        </xsl:when>
        <xsl:when test="$first = 'italic'">
          <I>
            <xsl:call-template name="rend">
              <xsl:with-param name="rend" select="$rest"/>
            </xsl:call-template>
          </I>
        </xsl:when>
        <xsl:when test="$first = 'underline'">
          <U>
            <xsl:call-template name="rend">
              <xsl:with-param name="rend" select="$rest"/>
            </xsl:call-template>
          </U>
        </xsl:when>
      </xsl:choose>
    </xsl:if>
  </xsl:template>

  <xsl:template match="hi[@rend='sup']">
    <SUP>
      <xsl:apply-templates/>
    </SUP>
  </xsl:template>
  <xsl:template match="hi[@rend='italic']">
    <I>
      <xsl:apply-templates/>
    </I>
  </xsl:template>
  <xsl:template match="hi">
    <I>
      <xsl:apply-templates/>
    </I>
  </xsl:template>

  <xsl:template match="emph">
    <xsl:choose>
      <xsl:when test="@rend = 'italic'">
        <I>
          <xsl:apply-templates/>
        </I>
      </xsl:when>
      <xsl:when test="@rend = 'underline'">
        <U>
          <xsl:apply-templates/>
        </U>
      </xsl:when>
      <xsl:when test="@rend = 'bold'">
        <B>
          <xsl:apply-templates/>
        </B>
      </xsl:when>
      <xsl:otherwise>
        <EM>
          <xsl:apply-templates/>
        </EM>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="corr">
    <xsl:text>&lt;</xsl:text>
    <xsl:apply-templates/>
    <xsl:text>&gt;</xsl:text>
  </xsl:template>

  <xsl:template match="add">
    <sup>
      <xsl:apply-templates/>
    </sup>
  </xsl:template>
  <xsl:template match="add[@hand='JFA' or @hand='MOG']">
    <xsl:text>[</xsl:text>
    <xsl:apply-templates/>
    <xsl:text>]</xsl:text>
  </xsl:template>
  <xsl:template match="del">
    <s>
      <xsl:apply-templates/>
    </s>
  </xsl:template>
  <xsl:template match="del[@hand='JFA']">
    <xsl:text>&#x2026;</xsl:text>
  </xsl:template>

  <xsl:template match="gap">
    <xsl:text>[&#x2026;]</xsl:text>
  </xsl:template>

  <xsl:template match="supplied">
    <xsl:text> !!!</xsl:text>
    <xsl:apply-templates/>
    <xsl:text>!!! </xsl:text>
  </xsl:template>

  <xsl:template match="list[@type='ordered']">
    <xsl:if test="parent::p">
      <xsl:text disable-output-escaping="yes">&lt;/p&gt;</xsl:text>
    </xsl:if>
    <xsl:apply-templates select="head"/>
    <OL>
      <xsl:apply-templates select="item"/>
    </OL>
    <xsl:if test="parent::p">
      <xsl:text disable-output-escaping="yes">&lt;p&gt;</xsl:text>
    </xsl:if>
  </xsl:template>

  <xsl:template match="list">
    <xsl:if test="parent::p">
      <xsl:text disable-output-escaping="yes">&lt;/p&gt;</xsl:text>
    </xsl:if>
    <xsl:apply-templates select="head"/>
    <UL>
      <xsl:apply-templates select="item"/>
    </UL>
    <xsl:if test="parent::p">
      <xsl:text disable-output-escaping="yes">&lt;p&gt;</xsl:text>
    </xsl:if>
  </xsl:template>

  <xsl:template match="text//item">
    <LI>
      <xsl:apply-templates/>
    </LI>
  </xsl:template>

  <xsl:template match="witList">
    <P>
      <xsl:text>Seznam izdaj:</xsl:text>
    </P>
    <UL>
        <xsl:apply-templates/>
      </UL>
  </xsl:template>

  <xsl:template match="witness">
    <LI>
      <A href="{$teiHeader-sl}#{@corresp}">
        <xsl:call-template name="witness"/>
      </A>
    </LI>
  </xsl:template>

  <!-- BIBLIOGRAHPY -->
  <xsl:template match="text//listBibl">
    <OL>
      <xsl:if test="./biblStruct/@n">
        <xsl:attribute name="start">
          <xsl:value-of select="biblStruct/@n"/>
        </xsl:attribute>
      </xsl:if>
      <xsl:apply-templates/>
    </OL>
  </xsl:template>

  <xsl:template match="text//bibl">
    <xsl:choose>
      <xsl:when test="parent::listBibl">
        <LI>
          <xsl:call-template name="anchor"/>
          <xsl:apply-templates/>
        </LI>
      </xsl:when>
      <xsl:otherwise>
        <I>
          <xsl:apply-templates/>
        </I>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="text//biblStruct">
    <LI>
      <A NAME="{@id}"/>
      <xsl:if test="$debug">
        <xsl:text>&#9;[</xsl:text>
        <xsl:value-of select="@id"/>
        <xsl:text>] </xsl:text>
      </xsl:if>
      <xsl:apply-templates/>
    </LI>
  </xsl:template>

  <xsl:template match="text//author">
    <B>
      <xsl:apply-templates/>
    </B>
    <xsl:if test="not(contains(.,'–'))">
      <xsl:text>: </xsl:text>
    </xsl:if>
  </xsl:template>

  <xsl:template match="text//monogr/title">
    <I>
      <xsl:apply-templates/>
    </I>
  </xsl:template>

  <xsl:template match="text//analytic/title">
    <xsl:text> </xsl:text>
    <xsl:choose>
      <xsl:when test="$debug">
        <FONT color="green">
          <xsl:apply-templates/>
        </FONT>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-templates/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="text//monogr/title">
    <xsl:text> </xsl:text>
    <xsl:choose>
      <xsl:when test="$debug">
        <FONT color="green">
          <xsl:apply-templates/>
        </FONT>
      </xsl:when>
      <xsl:otherwise>
        <I>
          <xsl:apply-templates/>
        </I>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="text//pubPlace">
    <xsl:text> </xsl:text>
    <xsl:choose>
      <xsl:when test="$debug">
        <FONT color="fuchsia">
          <xsl:apply-templates/>
        </FONT>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-templates/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="text//biblScope">
    <xsl:text> </xsl:text>
    <xsl:choose>
      <xsl:when test="$debug">
        <FONT color="blue">
          <xsl:apply-templates/>
        </FONT>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-templates/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!-- POINTING -->
  <xsl:template match="ptr">
    <SUP>
      <xsl:choose>
        <xsl:when test="@target">
          <xsl:for-each select="id(@target)">
            <A>
              <xsl:attribute name="href">
                <xsl:call-template name="href">
                  <xsl:with-param name="id" select="@id"/>
                </xsl:call-template>
              </xsl:attribute>
              <xsl:attribute name="title">
                <xsl:call-template name="title"/>
              </xsl:attribute>
              <xsl:text>&#x2191;</xsl:text>
            </A>
          </xsl:for-each>
        </xsl:when>
        <xsl:otherwise>
          <FONT color="red">&#x2191;?</FONT>
        </xsl:otherwise>
      </xsl:choose>
    </SUP>
  </xsl:template>

  <xsl:template match="ref">
    <A>
      <xsl:for-each select="id(@target)">
        <xsl:attribute name="href">
          <xsl:call-template name="href">
            <xsl:with-param name="id" select="@id"/>
          </xsl:call-template>
        </xsl:attribute>
        <xsl:attribute name="title">
          <xsl:call-template name="title"/>
        </xsl:attribute>
      </xsl:for-each>
      <xsl:apply-templates/>
    </A>
  </xsl:template>

  <xsl:template name="title">
    <xsl:choose>
      <xsl:when test="self::figure">
        <xsl:text>Slika: </xsl:text>
        <xsl:value-of select="normalize-space(figDesc)"/>
      </xsl:when>
      <xsl:when test="self::bibl">
        <xsl:value-of select="normalize-space(.)"/>
      </xsl:when>
      <xsl:when test="self::p">
        <xsl:value-of select="substring(normalize-space(.),1,40)"/>
        <xsl:if test="string-length(normalize-space(.)) &gt; 40">
          <xsl:text>...</xsl:text>
        </xsl:if>
      </xsl:when>
      <xsl:when test="head">
        <xsl:value-of select="normalize-space(head[1])"/>
      </xsl:when>
    </xsl:choose>
    <!--xsl:for-each select="ancestor::div">
      <xsl:text> / </xsl:text>
      <xsl:value-of select="head/text()"/>
    </xsl:for-each-->
  </xsl:template>

  <xsl:template match="xref">
    <xsl:choose>
      <xsl:when test="@url">
        <A href="{@url}">
          <U>
            <xsl:apply-templates/>
          </U>
        </A>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-templates/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!-- TEXT CRITICAL -->
  <xsl:template match="app">
    <xsl:param name="wit"/>
    <xsl:apply-templates select="rdg">
      <xsl:with-param name="wit" select="$wit"/>
    </xsl:apply-templates>
  </xsl:template>

  <xsl:template name="witness">
    <xsl:variable name="wit">
      <xsl:choose>
        <xsl:when test="self::witness">
          <xsl:value-of select="@sigil"/>
        </xsl:when>
        <xsl:when test="self::rdg">
          <xsl:value-of select="@wit"/>
        </xsl:when>
      </xsl:choose>
    </xsl:variable>
    <SPAN class="{$wit}">
      <xsl:if test="self::rdg">
        <xsl:attribute name="title">
          <xsl:value-of select="normalize-space(//witness[@sigil = $wit])"/>
        </xsl:attribute>
      </xsl:if>
      <xsl:choose>
        <xsl:when test="$wit = 'DS'">
          <xsl:text>[</xsl:text>
          <xsl:apply-templates/>
          <xsl:text>]</xsl:text>
        </xsl:when>
        <xsl:when test="$wit = 'KN'">
          <xsl:text>{</xsl:text>
          <xsl:apply-templates/>
          <xsl:text>}</xsl:text>
        </xsl:when>
      </xsl:choose>
    </SPAN>
  </xsl:template>

  <xsl:template match="rdg">
    <xsl:param name="wit"/>
    <xsl:choose>
      <xsl:when test="not(normalize-space($wit))">
        <xsl:call-template name="witness"/>
      </xsl:when>
      <xsl:when test="$wit = @wit">
        <xsl:apply-templates/>
        <!--xsl:choose>
          <xsl:when test="@wit='DS'">
            <font color="red">
              <xsl:apply-templates/>
            </font>
          </xsl:when>
          <xsl:when test="@wit='KN'">
            <font color="green">
              <xsl:apply-templates/>
            </font>
          </xsl:when>
        </xsl:choose-->
      </xsl:when>
    </xsl:choose>
  </xsl:template>

  <!-- NAMED TEMPLATES -->
  <xsl:template name="toc-main">
    <A name="TOC"/>
    <H2>Kazalo</H2>
    <xsl:if test="//teiHeader">
      <UL>
        <LI>
          <A HREF="{$teiHeader-sl}">
            <xsl:value-of select="$teiHeader-desc-sl"/>
          </A>
        </LI>
      </UL>
    </xsl:if>
    <UL>
      <xsl:apply-templates mode="toc" select="//body/div">
        <xsl:with-param name="level">1</xsl:with-param>
      </xsl:apply-templates>
    </UL>
    <xsl:if test="//back">
      <UL>
        <xsl:apply-templates mode="toc" select="//back">
          <xsl:with-param name="level">2</xsl:with-param>
        </xsl:apply-templates>
      </UL>
    </xsl:if>
  </xsl:template>

  <xsl:template name="chunk">
    <xsl:param name="wit"/>
    <xsl:param name="suffix">
      <xsl:choose>
        <xsl:when test="ancestor-or-self::back">
          <xsl:text>back</xsl:text>
        </xsl:when>
        <xsl:when test="normalize-space($wit)">
          <xsl:value-of select="$wit"/>
        </xsl:when>
      </xsl:choose>
    </xsl:param>
    <H1>
      <xsl:copy-of select="$def-title"/>
    </H1>
    <xsl:apply-templates select="head">
      <xsl:with-param name="wit" select="$wit"/>
    </xsl:apply-templates>
    <xsl:apply-templates select="docAuthor"/>
    <xsl:apply-templates select="witList"/>
    <H3>Kazalo</H3>
    <UL>
      <xsl:apply-templates mode="toc" select="div | divGen">
        <xsl:with-param name="level">4</xsl:with-param>
        <xsl:with-param name="wit" select="$wit"/>
        <xsl:with-param name="suffix" select="$suffix"/>
      </xsl:apply-templates>
      <xsl:if test=".//note[@place='end' or @place='foot'][1]">
        <LI>
          <A href="#notes">
            <xsl:text>opombe</xsl:text>
          </A>
        </LI>
      </xsl:if>
      <LI>
        <xsl:choose>
          <xsl:when test="$split">
            <A href="{$outName}.html#TOC">
              <xsl:text>na glavno kazalo</xsl:text>
            </A>
          </xsl:when>
          <xsl:otherwise>
            <A href="#TOC">
              <xsl:text>na glavno kazalo</xsl:text>
            </A>
          </xsl:otherwise>
        </xsl:choose>
      </LI>
    </UL>
    <HR/>
    <xsl:apply-templates select="div | divGen">
      <xsl:with-param name="wit" select="$wit"/>
    </xsl:apply-templates>
    <HR/>
    <xsl:if test=".//note and (not(normalize-space($wit))  or ancestor-or-self::back)">
      <A name="notes"/>
      <H3>Opombe </H3>
      <OL>
        <xsl:apply-templates select=".//note" mode="show"/>
      </OL>
      <xsl:if test="$split">
        <BR/>
        <BR/>
        <BR/>
        <BR/>
        <BR/>
        <BR/>
        <BR/>
        <BR/>
        <BR/>
        <BR/>
        <BR/>
        <BR/>
        <BR/>
        <BR/>
        <BR/>
        <BR/>
        <BR/>
        <BR/>
        <BR/>
        <BR/>
        <BR/>
        <BR/>
        <BR/>
        <BR/>
        <BR/>
        <BR/>
        <BR/>
        <BR/>
        <BR/>
        <BR/>
      </xsl:if>
    </xsl:if>
    <HR/>
  </xsl:template>

  <xsl:template name="outputChunk">
    <xsl:param name="wit"/>
    <xsl:param name="outFile" select="concat(@id,'.html')"/>
    <xsl:param name="absFile" select="concat($outDir,$outFile)"/>
    <xsl:param name="title">
      <xsl:value-of select="$id"/>
    </xsl:param>
    <xsl:param name="content"/>
    <xsl:choose>
      <xsl:when test="element-available('exsl:document')">
        <xsl:if test="$verbose='yes'">
          <xsl:message>Opening <xsl:value-of select="$absFile"/></xsl:message>
        </xsl:if>
        <exsl:document encoding="utf-8" method="html"
          doctype-public="-//W3C//DTD HTML 4.01 Transitional//EN" href="{$absFile}">
          <HTML>
            <xsl:comment>THIS FILE IS GENERATED FROM AN XML MASTER. DO NOT EDIT!</xsl:comment>
            <xsl:text>&#10;</xsl:text>
            <HEAD>
              <TITLE>
                <xsl:value-of select="normalize-space($title)"/>
              </TITLE>
              <META http-equiv="Content-Type" content="text/html; charset=utf-8"/>
              <STYLE TYPE="text/css">
                <xsl:value-of select="$css_style"/>
              </STYLE>
            </HEAD>
            <BODY>
              <xsl:copy-of select="$content"/>
              <xsl:copy-of select="$html-footer1"/>
              <xsl:if test="not(ancestor-or-self::teiHeader or descendant::teiHeader)">
                <xsl:copy-of select="$html-footer2"/>
              </xsl:if>
            </BODY>
          </HTML>
        </exsl:document>
        <xsl:if test="$verbose='yes'">
          <xsl:message>Closing <xsl:value-of select="$absFile"/></xsl:message>
        </xsl:if>
      </xsl:when>
      <xsl:otherwise>
        <xsl:if test="$verbose='yes'">
          <xsl:message>Creation of <xsl:value-of select="$absFile"/> not possible</xsl:message>
        </xsl:if>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!--xsl:template name="page-text">
  <xsl:for-each select="line">
    <xsl:call-template name="line"/>
  </xsl:for-each>
</xsl:template-->

  <xsl:template name="anchor">
    <xsl:param name="suffix"/>
    <xsl:param name="id"/>
    <A>
      <xsl:attribute name="name">
        <xsl:choose>
          <xsl:when test="$id">
            <xsl:value-of select="$id"/>
          </xsl:when>
          <xsl:when test="@id">
            <xsl:value-of select="@id"/>
          </xsl:when>
          <xsl:otherwise>
            <xsl:value-of select="generate-id(.)"/>
          </xsl:otherwise>
        </xsl:choose>
        <xsl:value-of select="$suffix"/>
      </xsl:attribute>
    </A>
  </xsl:template>

  <xsl:template name="href">
    <xsl:param name="suffix">
      <xsl:choose>
        <xsl:when test="ancestor-or-self::back">
          <xsl:text>back</xsl:text>
        </xsl:when>
        <xsl:when test="ancestor-or-self::div[@type='part']">
          <xsl:value-of select="ancestor-or-self::div[@type='part']/@id"/>
        </xsl:when>
        <xsl:when test="ancestor-or-self::teiHeader">
          <xsl:value-of select="teiHeader-sl"/>
        </xsl:when>
      </xsl:choose>
    </xsl:param>
    <xsl:param name="id">
      <xsl:choose>
        <xsl:when test="@id">
          <xsl:value-of select="@id"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="generate-id(.)"/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:param>
    <xsl:if test="$split">
      <xsl:value-of select="$outName"/>
      <xsl:if test="normalize-space($suffix)">
        <xsl:value-of select="concat('-',$suffix)"/>
      </xsl:if>
      <xsl:text>.html</xsl:text>
    </xsl:if>
    <xsl:text>#</xsl:text>
    <xsl:value-of select="$id"/>
  </xsl:template>

  <!-- TEI Header -> HTML                                                     -->
  <!-- 2006-07-25                                                             -->
  <!-- Tomaz Erjavec                                                          -->
  <!--                                                                        -->

  <xsl:param name="tei-url">http://www.tei-c.org.uk/P4X/</xsl:param>
  <!--xsl:param name="tei-url">TEI_P4/</xsl:param-->
  <xsl:param name="lang">sl</xsl:param>

  <xsl:template match="teiHeader">
    <!--xsl:call-template name="navpanel"/-->
    <H1 align="left">
      <A NAME="{@id}"/>
      <xsl:copy-of select="$LABEL-teiHeader"/>
    </H1>
    <TABLE summary="TEI header">
      <xsl:if test="not(@type = 'text')">
        <TR>
          <TH align="left">
            <xsl:value-of select="$LABELATT-type"/>
            <xsl:text>:</xsl:text>
          </TH>
          <TD>
            <xsl:value-of select="@type"/>
          </TD>
        </TR>
      </xsl:if>
      <xsl:if test="@lang">
        <TR>
          <TH align="left">
            <xsl:value-of select="$LABELATT-lang"/>
            <xsl:text>:</xsl:text>
          </TH>
          <TD>
            <xsl:value-of select="id(@lang)"/>
          </TD>
        </TR>
      </xsl:if>
      <xsl:if test="@creator">
        <TR>
          <TH align="left">
            <xsl:value-of select="$LABELATT-creator"/>
            <xsl:text>:</xsl:text>
          </TH>
          <TD>
            <xsl:value-of select="@creator"/>
          </TD>
        </TR>
      </xsl:if>
      <xsl:if test="@date.created or @date.updated">
        <TR>
          <TH align="left">
            <xsl:value-of select="$LABELATT-date"/>
            <xsl:text>:</xsl:text>
          </TH>
          <xsl:if test="@date.created">
            <TD>
              <xsl:value-of select="@date.created"/>
              <xsl:text> (</xsl:text>
              <xsl:value-of select="$LABELATT-date.created"/>
              <xsl:text>) </xsl:text>
            </TD>
          </xsl:if>
          <xsl:if test="@date.updated">
            <TD>
              <xsl:value-of select="@date.updated"/>
              <xsl:text> (</xsl:text>
              <xsl:value-of select="$LABELATT-date.updated"/>
              <xsl:text>) </xsl:text>
            </TD>
          </xsl:if>
        </TR>
      </xsl:if>
    </TABLE>
    <xsl:apply-templates/>
    <!--xsl:call-template name="navpanel"/-->
  </xsl:template>

  <xsl:template match="fileDesc">
    <xsl:call-template name="h2-dl">
      <xsl:with-param name="name">fileDesc</xsl:with-param>
      <xsl:with-param name="label" select="$LABEL-fileDesc"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="encodingDesc">
    <xsl:call-template name="h2-dl">
      <xsl:with-param name="name">encodingDesc</xsl:with-param>
      <xsl:with-param name="label" select="$LABEL-encodingDesc"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="profileDesc">
    <xsl:call-template name="h2-dl">
      <xsl:with-param name="name">profileDesc</xsl:with-param>
      <xsl:with-param name="label" select="$LABEL-profileDesc"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="revisionDesc">
    <xsl:call-template name="h2-ul">
      <xsl:with-param name="name">revisionDesc</xsl:with-param>
      <xsl:with-param name="label" select="$LABEL-revisionDesc"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="sourceDesc">
    <xsl:call-template name="dt-dl">
      <xsl:with-param name="label" select="$LABEL-sourceDesc"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="projectDesc">
    <xsl:call-template name="dt-dl">
      <xsl:with-param name="label" select="$LABEL-projectDesc"/>
    </xsl:call-template>
  </xsl:template>

  <!--variantEncoding method='parallel-segmentation' location='internal'/-->
  <xsl:template match="variantEncoding">
    <DT>
      <B>
        <xsl:copy-of select="$LABEL-variantEncoding"/>
      </B>
    </DT>
    <xsl:if test="@method = 'parallel-segmentation'">
      <DD>Metoda: vzporedna segmentacija</DD>
    </xsl:if>
    <xsl:if test="@location = 'internal'">
      <DD>Lokacija: v besedilu</DD>
    </xsl:if>
  </xsl:template>

  <xsl:template match="titleStmt">
    <xsl:call-template name="dt-dl">
      <xsl:with-param name="label" select="$LABEL-titleStmt"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="principal">
    <xsl:call-template name="dt-dl">
      <xsl:with-param name="label" select="$LABEL-principal"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="publicationStmt">
    <xsl:call-template name="dt-dl">
      <xsl:with-param name="label" select="$LABEL-publicationStmt"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="notesStmt">
    <xsl:call-template name="dt-dl">
      <xsl:with-param name="label" select="$LABEL-notesStmt"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="teiHeader//respStmt">
    <xsl:choose>
      <xsl:when test="parent::change">
        <xsl:apply-templates/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:call-template name="dt-dl">
          <xsl:with-param name="label" select="$LABEL-respStmt"/>
        </xsl:call-template>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="editionStmt[p]">
    <xsl:call-template name="dt-dd">
      <xsl:with-param name="label" select="$LABEL-editionStmt"/>
    </xsl:call-template>
  </xsl:template>
  <xsl:template match="editionStmt">
    <xsl:call-template name="dt-dl">
      <xsl:with-param name="label" select="$LABEL-editionStmt"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="editorialDecl">
    <xsl:call-template name="dt-dl">
      <xsl:with-param name="label" select="$LABEL-editorialDecl"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="tagsDecl">
    <xsl:call-template name="dt-dl">
      <xsl:with-param name="label" select="$LABEL-tagsDecl"/>
    </xsl:call-template>
  </xsl:template>

  <!-- USER EXTENSION -->
  <xsl:template match="charDesc">
    <DT>
      <B>
        <xsl:copy-of select="$LABEL-charDesc"/>
      </B>
      <xsl:text>:</xsl:text>
    </DT>
    <DD>
      <xsl:apply-templates select="desc"/>
    </DD>
    <DD>
      <DL>
        <xsl:for-each select="char">
          <DT><xsl:value-of select="charName"/> (<xsl:value-of select="@id"/>)</DT>
          <xsl:for-each select="charProp">
            <DD>
              <xsl:value-of select="localName"/>=<xsl:value-of select="value"/>
            </DD>
          </xsl:for-each>
          <xsl:for-each select="mapping">
            <DD><xsl:value-of select="@type"/> = <BIG>[<xsl:value-of select="."/>]</BIG></DD>
          </xsl:for-each>
        </xsl:for-each>
      </DL>
    </DD>
  </xsl:template>

  <xsl:template match="classDecl">
    <xsl:call-template name="dt-dl">
      <xsl:with-param name="label" select="$LABEL-classDecl"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="fsdDecl">
    <xsl:call-template name="dt-dl">
      <xsl:with-param name="label" select="$LABEL-fsdDecl"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="teiHeader//fLib">
    <DT>
      <xsl:copy-of select="$LABEL-flib"/>
    </DT>
    <xsl:if test="@type">
      <DD>
        <xsl:value-of select="@type"/>
      </DD>
    </xsl:if>
  </xsl:template>

  <xsl:template match="teiHeader//fsLib">
    <DT>
      <xsl:copy-of select="$LABEL-fslib"/>
    </DT>
    <xsl:if test="@type">
      <DD>
        <xsl:value-of select="@type"/>
      </DD>
    </xsl:if>
  </xsl:template>

  <xsl:template match="taxonomy">
    <xsl:call-template name="dt-dl">
      <xsl:with-param name="label" select="$LABEL-taxonomy"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="category">
    <xsl:call-template name="dt-dl">
      <xsl:with-param name="label">
        <xsl:copy-of select="$LABEL-category"/>
        <xsl:if test="@id">
          <xsl:text> "</xsl:text>
          <xsl:value-of select="@id"/>
          <xsl:text>"</xsl:text>
        </xsl:if>
      </xsl:with-param>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="catDesc">
    <DT>
      <xsl:apply-templates/>
    </DT>
  </xsl:template>

  <xsl:template match="correction">
    <xsl:call-template name="dt-dd">
      <xsl:with-param name="label" select="$LABEL-correction"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="hyphenation">
    <xsl:call-template name="dt-dd">
      <xsl:with-param name="label" select="$LABEL-hyphenation"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="normalization">
    <xsl:call-template name="dt-dd">
      <xsl:with-param name="label" select="$LABEL-normalization"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="quotation">
    <xsl:call-template name="dt-dd">
      <xsl:with-param name="label" select="$LABEL-quotation"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="segmentation">
    <xsl:call-template name="dt-dd">
      <xsl:with-param name="label" select="$LABEL-segmentation"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="interpretation">
    <xsl:call-template name="dt-dd">
      <xsl:with-param name="label" select="$LABEL-interpretation"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="stdVals">
    <xsl:call-template name="dt-dd">
      <xsl:with-param name="label" select="$LABEL-stdVals"/>
    </xsl:call-template>
  </xsl:template>

  <!--
  <xsl:choose>
    <xsl:when test="false()">
    </xsl:when>
    <xsl:otherwise>
    </xsl:otherwise>
  </xsl:choose>
-->

  <xsl:template match="teiHeader//address">
    <xsl:call-template name="dt-dd">
      <xsl:with-param name="label" select="$LABEL-address"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="teiHeader//availability">
    <xsl:call-template name="dt-dd">
      <xsl:with-param name="label">
        <xsl:copy-of select="$LABEL-availability"/>
        <xsl:if test="@status">
          <xsl:text> (</xsl:text>
          <xsl:value-of select="@status"/>
          <xsl:text>) </xsl:text>
        </xsl:if>
      </xsl:with-param>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="teiHeader//idno">
    <xsl:call-template name="dt-dd">
      <xsl:with-param name="label">
        <xsl:copy-of select="$LABEL-idno"/>
      </xsl:with-param>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="teiHeader//xref">
    <xsl:choose>
      <xsl:when test="@url and (@from = 'ROOT')">
        <A href="{@url}">
          <xsl:apply-templates/>
        </A>
      </xsl:when>
      <xsl:when test="@url">
        <A href="{@url}#{@from}">
          <xsl:apply-templates/>
        </A>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-templates/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="teiHeader//xptr">
    <xsl:text>&lt;</xsl:text>
    <xsl:choose>
      <xsl:when test="@url and (@from = 'ROOT')">
        <A href="{@url}">
          <xsl:value-of select="@url"/>
        </A>
      </xsl:when>
      <xsl:when test="@url">
        <A href="{@url}#{@from}">
          <xsl:value-of select="@url"/>#<xsl:value-of select="@from"/>
        </A>
      </xsl:when>
      <xsl:otherwise> Arrgfh! Argh!! </xsl:otherwise>
    </xsl:choose>
    <xsl:text>&gt;</xsl:text>
  </xsl:template>

  <xsl:template match="extent">
    <xsl:call-template name="dt-dd">
      <xsl:with-param name="label" select="$LABEL-extent"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="teiHeader//imprint">
    <xsl:call-template name="dt-dl">
      <xsl:with-param name="label" select="$LABEL-imprint"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="teiHeader//distributor">
    <xsl:call-template name="dt-dd">
      <xsl:with-param name="label" select="$LABEL-distributor"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="teiHeader//biblScope">
    <xsl:choose>
      <xsl:when test="parent::bibl">
        <xsl:apply-templates/>
        <xsl:text> </xsl:text>
      </xsl:when>
      <xsl:otherwise>
        <xsl:call-template name="dt-dd">
          <xsl:with-param name="label" select="$LABEL-biblScope"/>
        </xsl:call-template>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="teiHeader//pubPlace">
    <xsl:choose>
      <xsl:when test="parent::bibl">
        <xsl:apply-templates/>
        <xsl:text> </xsl:text>
      </xsl:when>
      <xsl:otherwise>
        <xsl:call-template name="dt-dd">
          <xsl:with-param name="label" select="$LABEL-pubPlace"/>
        </xsl:call-template>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="teiHeader//publisher">
    <xsl:choose>
      <xsl:when test="parent::bibl">
        <xsl:apply-templates/>
        <xsl:text> </xsl:text>
      </xsl:when>
      <xsl:when test="*">
        <xsl:call-template name="dt-dl">
          <xsl:with-param name="label" select="$LABEL-publisher"/>
        </xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
        <xsl:call-template name="dt-dd">
          <xsl:with-param name="label" select="$LABEL-publisher"/>
        </xsl:call-template>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="teiHeader//title">
    <xsl:choose>
      <xsl:when test="parent::bibl">
        <EM>
          <xsl:apply-templates/>
        </EM>
        <xsl:text> </xsl:text>
      </xsl:when>
      <xsl:otherwise>
        <xsl:call-template name="dt-dd">
          <xsl:with-param name="label" select="$LABEL-title"/>
        </xsl:call-template>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="langUsage">
    <xsl:call-template name="dt-dd">
      <xsl:with-param name="label" select="$LABEL-langUsage"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="handList">
    <xsl:call-template name="dt-ul">
      <xsl:with-param name="label" select="$LABEL-handList"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="hand">
    <LI>
      <B>
        <xsl:value-of select="@id"/>
      </B>
      <xsl:text> = </xsl:text>
      <xsl:value-of select="@scribe"/>
    </LI>
  </xsl:template>

  <xsl:template match="teiHeader//listBibl">
    <xsl:choose>
      <xsl:when test="../sourceDesc">
        <xsl:call-template name="dt-ul">
          <xsl:with-param name="label" select="$LABEL-listBibl"/>
        </xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
        <UL>
          <xsl:apply-templates/>
        </UL>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="tagUsage">
    <DT>
      <B>
        <A>
          <xsl:attribute name="href">
            <xsl:call-template name="teip4-elts">
              <xsl:with-param name="gi" select="@gi"/>
            </xsl:call-template>
          </xsl:attribute>
          <xsl:value-of select="@gi"/>
        </A>
      </B>
      <xsl:text> = </xsl:text>
      <xsl:value-of select="@occurs"/>
    </DT>
    <xsl:if test=".">
      <DD>
        <xsl:apply-templates/>
      </DD>
    </xsl:if>
  </xsl:template>

  <xsl:template match="teiHeader//addrLine">
    <xsl:apply-templates/>
    <BR/>
  </xsl:template>

  <xsl:template match="teiHeader//author">
    <xsl:call-template name="dt-dd">
      <xsl:with-param name="label" select="$LABEL-author"/>
    </xsl:call-template>
  </xsl:template>

  <!--xsl:template match="teiHeader//author">
  <xsl:apply-templates/>
  <xsl:text> </xsl:text>
</xsl:template-->

  <xsl:template match="titleStmt//editor">
    <xsl:call-template name="dt-dd">
      <xsl:with-param name="label" select="$LABEL-titleStmt-editor"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="teiHeader//editor">
    <xsl:apply-templates/>
    <xsl:text> </xsl:text>
    <xsl:copy-of select="$LABEL-editor"/>
    <xsl:text> </xsl:text>
  </xsl:template>

  <xsl:template match="change">
    <LI>
      <xsl:apply-templates/>
    </LI>
  </xsl:template>

  <xsl:template match="teiHeader//resp">
    <xsl:choose>
      <xsl:when test="ancestor::revisionDesc">
        <xsl:text> (</xsl:text>
        <xsl:apply-templates/>
        <xsl:text>) </xsl:text>
      </xsl:when>
      <xsl:when test="ancestor::principal">
        <DT>
          <xsl:apply-templates/>
        </DT>
      </xsl:when>
      <xsl:otherwise>
        <DT>
          <xsl:apply-templates/>
          <xsl:if test="following-sibling::*[1][name]">
            <xsl:text>: </xsl:text>
          </xsl:if>
        </DT>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="teiHeader//name">
    <xsl:choose>
      <xsl:when test="ancestor::titleStmt or ancestor::editionStmt">
        <DD>
          <xsl:apply-templates/>
        </DD>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-templates/>
        <xsl:if test="following-sibling::name">, </xsl:if>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="teiHeader//edition">
    <xsl:choose>
      <xsl:when test="parent::*">
        <!-- we want this everywhere -->
        <xsl:call-template name="dt-dd">
          <xsl:with-param name="label" select="$LABEL-edition"/>
        </xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
        <BR/>
        <B>
          <xsl:copy-of select="$LABEL-edition"/>
        </B>
        <xsl:text>: </xsl:text>
        <xsl:apply-templates/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="teiHeader//bibl">
    <xsl:choose>
      <xsl:when test="ancestor::listBibl">
        <LI>
          <xsl:call-template name="anchor"/>
          <xsl:call-template name="dt-dl">
            <xsl:with-param name="label" select="$LABEL-bibl"/>
          </xsl:call-template>
        </LI>
      </xsl:when>
      <xsl:otherwise>
        <xsl:call-template name="dt-dl">
          <xsl:with-param name="label" select="$LABEL-bibl"/>
        </xsl:call-template>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="teiHeader//monogr">
    <xsl:call-template name="dt-dl">
      <xsl:with-param name="label" select="$LABEL-monogr"/>
    </xsl:call-template>
  </xsl:template>
  <xsl:template match="teiHeader//analytic">
    <xsl:call-template name="dt-dl">
      <xsl:with-param name="label" select="$LABEL-analytic"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="teiHeader//date">
    <xsl:choose>
      <xsl:when test="parent::publicationStmt or parent::imprint">
        <xsl:call-template name="dt-dd">
          <xsl:with-param name="label" select="$LABEL-date"/>
        </xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
        <EM>
          <xsl:apply-templates/>
        </EM>
        <xsl:text> </xsl:text>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="teiHeader//foreign">
    <I>
      <xsl:apply-templates/>
    </I>
  </xsl:template>

  <xsl:template match="teiHeader//language">
    <A NAME="{@id}">
      <B>
        <xsl:value-of select="@id"/>
      </B>
    </A>
    <xsl:text> = </xsl:text>
    <xsl:apply-templates/>
  </xsl:template>

  <xsl:template match="teiHeader//p">
    <xsl:choose>
      <xsl:when
        test="parent::profileDesc or parent::projectDesc or parent::revisionDesc or parent::sourceDesc">
        <DD>
          <xsl:apply-templates/>
        </DD>
      </xsl:when>
      <xsl:otherwise>
        <P>
          <xsl:apply-templates/>
        </P>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="teiHeader//list">
    <xsl:choose>
      <xsl:when test="parent::revisionDesc">
        <xsl:apply-templates/>
      </xsl:when>
      <xsl:otherwise>
        <UL>
          <xsl:apply-templates/>
        </UL>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="teiHeader//item">
    <xsl:choose>
      <xsl:when test="parent::change">
        <BR/>
        <xsl:apply-templates/>
      </xsl:when>
      <xsl:otherwise>
        <LI>
          <xsl:apply-templates/>
        </LI>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="teiHeader//note">
    <DT>
      <B>
        <xsl:copy-of select="$LABEL-note"/>
      </B>
      <xsl:if test="@type">
        <xsl:text> (</xsl:text>
        <xsl:value-of select="@type"/>
        <xsl:text>)</xsl:text>
      </xsl:if>
      <xsl:text>:</xsl:text>
    </DT>
    <DD>
      <xsl:apply-templates/>
    </DD>
  </xsl:template>

  <xsl:template match="teiHeader//q">
    <xsl:text>"</xsl:text>
    <xsl:apply-templates/>
    <xsl:text>"</xsl:text>
  </xsl:template>

  <xsl:template match="teiHeader//term">
    <I>
      <xsl:apply-templates/>
    </I>
  </xsl:template>

  <xsl:template match="teiHeader//seg">
    <xsl:apply-templates/>
    <xsl:if test="@lang">
      <xsl:text> (</xsl:text>
      <xsl:value-of select="id(@lang)"/>
      <xsl:text>) </xsl:text>
    </xsl:if>
    <BR/>
  </xsl:template>

  <xsl:template match="lb">
    <BR/>
  </xsl:template>

  <xsl:template name="h2-dl">
    <xsl:param name="name"/>
    <xsl:param name="label">???</xsl:param>
    <H2>
      <A NAME="{$name}"/>
      <xsl:copy-of select="$label"/>
    </H2>
    <DL>
      <xsl:apply-templates/>
    </DL>
  </xsl:template>

  <xsl:template name="h2-ul">
    <xsl:param name="name"/>
    <xsl:param name="label">???</xsl:param>
    <H2>
      <A NAME="{$name}"/>
      <xsl:copy-of select="$label"/>
    </H2>
    <UL>
      <xsl:apply-templates/>
    </UL>
  </xsl:template>

  <xsl:template name="h3-dl">
    <xsl:param name="label">???</xsl:param>
    <H3>
      <xsl:copy-of select="$label"/>
    </H3>
    <DL>
      <xsl:apply-templates/>
    </DL>
  </xsl:template>

  <xsl:template name="dt-dd">
    <xsl:param name="label">???</xsl:param>
    <DT>
      <B>
        <xsl:copy-of select="$label"/>
      </B>
      <xsl:text>:</xsl:text>
    </DT>
    <DD>
      <xsl:apply-templates/>
    </DD>
  </xsl:template>

  <xsl:template name="dt-dl">
    <xsl:param name="label">???</xsl:param>
    <DT>
      <B>
        <xsl:copy-of select="$label"/>
      </B>
      <xsl:text>:</xsl:text>
    </DT>
    <DD>
      <DL>
        <xsl:apply-templates/>
      </DL>
    </DD>
  </xsl:template>

  <xsl:template name="dt-ul">
    <xsl:param name="label">???</xsl:param>
    <DT>
      <B>
        <xsl:copy-of select="$label"/>
      </B>
      <xsl:text>:</xsl:text>
    </DT>
    <DD>
      <UL>
        <xsl:apply-templates/>
      </UL>
    </DD>
  </xsl:template>

  <xsl:template name="teip4-elts">
    <xsl:param name="gi"/>
    <xsl:value-of select="$tei-url"/>
    <!-- TEI P4 Chp.35: Elements -->
    <xsl:choose>
      <xsl:when test="$gi='abbr'">ref-ABBR.html</xsl:when>
      <xsl:when test="$gi='activity'">ref-ACTIVITY.html</xsl:when>
      <xsl:when test="$gi='actor'">ref-ACTOR.html</xsl:when>
      <xsl:when test="$gi='add'">ref-ADD.html</xsl:when>
      <xsl:when test="$gi='addName'">ref-ADDNAME.html</xsl:when>
      <xsl:when test="$gi='address'">ref-ADDRESS.html</xsl:when>
      <xsl:when test="$gi='addrLine'">ref-ADDRLINE.html</xsl:when>
      <xsl:when test="$gi='addSpan'">ref-ADDSPAN.html</xsl:when>
      <xsl:when test="$gi='admin'">ref-ADMIN.html</xsl:when>
      <xsl:when test="$gi='affiliation'">ref-AFFILIAT.html</xsl:when>
      <xsl:when test="$gi='alt'">ref-ALT.html</xsl:when>
      <xsl:when test="$gi='altGrp'">ref-ALTGRP.html</xsl:when>
      <xsl:when test="$gi='analytic'">ref-ANALYTIC.html</xsl:when>
      <xsl:when test="$gi='anchor'">ref-ANCHOR.html</xsl:when>
      <xsl:when test="$gi='ab'">ref-ANONB.html</xsl:when>
      <xsl:when test="$gi='any'">ref-ANY.html</xsl:when>
      <xsl:when test="$gi='app'">ref-APP.html</xsl:when>
      <xsl:when test="$gi='arc'">ref-ARC.html</xsl:when>
      <xsl:when test="$gi='argument'">ref-ARGUMENT.html</xsl:when>
      <xsl:when test="$gi='att'">ref-ATT.html</xsl:when>
      <xsl:when test="$gi='attDef'">ref-ATTDEF.html</xsl:when>
      <xsl:when test="$gi='attlDecl'">ref-ATTLDECL.html</xsl:when>
      <xsl:when test="$gi='attList'">ref-ATTLIST.html</xsl:when>
      <xsl:when test="$gi='attName'">ref-ATTNAME.html</xsl:when>
      <xsl:when test="$gi='author'">ref-AUTHOR.html</xsl:when>
      <xsl:when test="$gi='authority'">ref-AUTHORTY.html</xsl:when>
      <xsl:when test="$gi='availability'">ref-AVAIL.html</xsl:when>
      <xsl:when test="$gi='back'">ref-BACK.html</xsl:when>
      <xsl:when test="$gi='baseWsd'">ref-BASEWSD.html</xsl:when>
      <xsl:when test="$gi='bibl'">ref-BIBL.html</xsl:when>
      <xsl:when test="$gi='biblFull'">ref-BIBLFULL.html</xsl:when>
      <xsl:when test="$gi='biblScope'">ref-BIBLSCOP.html</xsl:when>
      <xsl:when test="$gi='biblStruct'">ref-BIBLSTRU.html</xsl:when>
      <xsl:when test="$gi='bicond'">ref-BICOND.html</xsl:when>
      <xsl:when test="$gi='birth'">ref-BIRTH.html</xsl:when>
      <xsl:when test="$gi='bloc'">ref-BLOC.html</xsl:when>
      <xsl:when test="$gi='body'">ref-BODY.html</xsl:when>
      <xsl:when test="$gi='broadcast'">ref-BROADCAS.html</xsl:when>
      <xsl:when test="$gi='byline'">ref-BYLINE.html</xsl:when>
      <xsl:when test="$gi='c'">ref-C.html</xsl:when>
      <xsl:when test="$gi='caesura'">ref-CAESURA.html</xsl:when>
      <xsl:when test="$gi='camera'">ref-CAMERA.html</xsl:when>
      <xsl:when test="$gi='caption'">ref-CAPTION.html</xsl:when>
      <xsl:when test="$gi='case'">ref-CASE.html</xsl:when>
      <xsl:when test="$gi='castGroup'">ref-CASTGRP.html</xsl:when>
      <xsl:when test="$gi='castItem'">ref-CASTITEM.html</xsl:when>
      <xsl:when test="$gi='castList'">ref-CASTLIST.html</xsl:when>
      <xsl:when test="$gi='catDesc'">ref-CATDESC.html</xsl:when>
      <xsl:when test="$gi='category'">ref-CATEGORY.html</xsl:when>
      <xsl:when test="$gi='catRef'">ref-CATREF.html</xsl:when>
      <xsl:when test="$gi='cell'">ref-CELL.html</xsl:when>
      <xsl:when test="$gi='certainty'">ref-CERTAIN.html</xsl:when>
      <xsl:when test="$gi='change'">ref-CHANGE.html</xsl:when>
      <xsl:when test="$gi='channel'">ref-CHANNEL.html</xsl:when>
      <xsl:when test="$gi='children'">ref-CHILDREN.html</xsl:when>
      <xsl:when test="$gi='cit'">ref-CIT.html</xsl:when>
      <xsl:when test="$gi='cl'">ref-CL.html</xsl:when>
      <xsl:when test="$gi='classDecl'">ref-CLASDECL.html</xsl:when>
      <xsl:when test="$gi='class'">ref-CLASS.html</xsl:when>
      <xsl:when test="$gi='classCode'">ref-CLASSCOD.html</xsl:when>
      <xsl:when test="$gi='classDoc'">ref-CLASSDOC.html</xsl:when>
      <xsl:when test="$gi='classes'">ref-CLASSES.html</xsl:when>
      <xsl:when test="$gi='closer'">ref-CLOSER.html</xsl:when>
      <xsl:when test="$gi='cb'">ref-COLBR.html</xsl:when>
      <xsl:when test="$gi='colloc'">ref-COLLOC.html</xsl:when>
      <xsl:when test="$gi='cond'">ref-COND.html</xsl:when>
      <xsl:when test="$gi='constitution'">ref-CONSTITN.html</xsl:when>
      <xsl:when test="$gi='corr'">ref-CORR.html</xsl:when>
      <xsl:when test="$gi='correction'">ref-CORRECTN.html</xsl:when>
      <xsl:when test="$gi='country'">ref-COUNTRY.html</xsl:when>
      <xsl:when test="$gi='creation'">ref-CREATN.html</xsl:when>
      <xsl:when test="$gi='damage'">ref-DAMAGE.html</xsl:when>
      <xsl:when test="$gi='dataDesc'">ref-DATADESC.html</xsl:when>
      <xsl:when test="$gi='datatype'">ref-DATATYPE.html</xsl:when>
      <xsl:when test="$gi='date'">ref-DATE.html</xsl:when>
      <xsl:when test="$gi='dateline'">ref-DATELINE.html</xsl:when>
      <xsl:when test="$gi='dateRange'">ref-DATERANG.html</xsl:when>
      <xsl:when test="$gi='dateStruct'">ref-DATESTRU.html</xsl:when>
      <xsl:when test="$gi='day'">ref-DAY.html</xsl:when>
      <xsl:when test="$gi='def'">ref-DEF.html</xsl:when>
      <xsl:when test="$gi='default'">ref-DEFAULT.html</xsl:when>
      <xsl:when test="$gi='del'">ref-DEL.html</xsl:when>
      <xsl:when test="$gi='delSpan'">ref-DELSPAN.html</xsl:when>
      <xsl:when test="$gi='derivation'">ref-DERIVATN.html</xsl:when>
      <xsl:when test="$gi='desc'">ref-DESC.html</xsl:when>
      <xsl:when test="$gi='descrip'">ref-DESCRIP.html</xsl:when>
      <xsl:when test="$gi='dft'">ref-DFT.html</xsl:when>
      <xsl:when test="$gi='dictScrap'">ref-DICSCRAP.html</xsl:when>
      <xsl:when test="$gi='egDI'">ref-DIEG.html</xsl:when>
      <xsl:when test="$gi='direction'">ref-DIRECTN.html</xsl:when>
      <xsl:when test="$gi='distance'">ref-DISTANCE.html</xsl:when>
      <xsl:when test="$gi='distinct'">ref-DISTINCT.html</xsl:when>
      <xsl:when test="$gi='distributor'">ref-DISTRIB.html</xsl:when>
      <xsl:when test="$gi='div'">ref-DIV.html</xsl:when>
      <xsl:when test="$gi='div0'">ref-DIV0.html</xsl:when>
      <xsl:when test="$gi='div1'">ref-DIV1.html</xsl:when>
      <xsl:when test="$gi='div2'">ref-DIV2.html</xsl:when>
      <xsl:when test="$gi='div3'">ref-DIV3.html</xsl:when>
      <xsl:when test="$gi='div4'">ref-DIV4.html</xsl:when>
      <xsl:when test="$gi='div5'">ref-DIV5.html</xsl:when>
      <xsl:when test="$gi='div6'">ref-DIV6.html</xsl:when>
      <xsl:when test="$gi='div7'">ref-DIV7.html</xsl:when>
      <xsl:when test="$gi='divGen'">ref-DIVGEN.html</xsl:when>
      <xsl:when test="$gi='docAuthor'">ref-DOCAUTH.html</xsl:when>
      <xsl:when test="$gi='docDate'">ref-DOCDATE.html</xsl:when>
      <xsl:when test="$gi='docEdition'">ref-DOCEDITN.html</xsl:when>
      <xsl:when test="$gi='docImprint'">ref-DOCIMPRT.html</xsl:when>
      <xsl:when test="$gi='docTitle'">ref-DOCTITLE.html</xsl:when>
      <xsl:when test="$gi='domain'">ref-DOMAIN.html</xsl:when>
      <xsl:when test="$gi='role'">ref-DRROLE.html</xsl:when>
      <xsl:when test="$gi='editorialDecl'">ref-EDDECL.html</xsl:when>
      <xsl:when test="$gi='edition'">ref-EDITION.html</xsl:when>
      <xsl:when test="$gi='editor'">ref-EDITOR.html</xsl:when>
      <xsl:when test="$gi='editionStmt'">ref-EDSTMT.html</xsl:when>
      <xsl:when test="$gi='education'">ref-EDUCN.html</xsl:when>
      <xsl:when test="$gi='eLeaf'">ref-ELEAF.html</xsl:when>
      <xsl:when test="$gi='elemDecl'">ref-ELEMDECL.html</xsl:when>
      <xsl:when test="$gi='emph'">ref-EMPH.html</xsl:when>
      <xsl:when test="$gi='encodingDesc'">ref-ENCDESC.html</xsl:when>
      <xsl:when test="$gi='entDoc'">ref-ENTDOC.html</xsl:when>
      <xsl:when test="$gi='entName'">ref-ENTNAME.html</xsl:when>
      <xsl:when test="$gi='entry'">ref-ENTRY.html</xsl:when>
      <xsl:when test="$gi='entryFree'">ref-ENTRYFR.html</xsl:when>
      <xsl:when test="$gi='epigraph'">ref-EPIGRAPH.html</xsl:when>
      <xsl:when test="$gi='epilogue'">ref-EPILOGUE.html</xsl:when>
      <xsl:when test="$gi='equipment'">ref-EQUIPMEN.html</xsl:when>
      <xsl:when test="$gi='equiv'">ref-EQUIV.html</xsl:when>
      <xsl:when test="$gi='eTree'">ref-ETREE.html</xsl:when>
      <xsl:when test="$gi='etym'">ref-ETYM.html</xsl:when>
      <xsl:when test="$gi='event'">ref-EVENT.html</xsl:when>
      <xsl:when test="$gi='exceptions'">ref-EXCEPTNS.html</xsl:when>
      <xsl:when test="$gi='exemplum'">ref-EXEMPLUM.html</xsl:when>
      <xsl:when test="$gi='expan'">ref-EXPAN.html</xsl:when>
      <xsl:when test="$gi='extent'">ref-EXTENT.html</xsl:when>
      <xsl:when test="$gi='f'">ref-F.html</xsl:when>
      <xsl:when test="$gi='factuality'">ref-FACTUAL.html</xsl:when>
      <xsl:when test="$gi='fAlt'">ref-FALT.html</xsl:when>
      <xsl:when test="$gi='fDecl'">ref-FDECL.html</xsl:when>
      <xsl:when test="$gi='fDescr'">ref-FDESCR.html</xsl:when>
      <xsl:when test="$gi='figDesc'">ref-FIGDESC.html</xsl:when>
      <xsl:when test="$gi='figure'">ref-FIGURE.html</xsl:when>
      <xsl:when test="$gi='fileDesc'">ref-FILDESC.html</xsl:when>
      <xsl:when test="$gi='files'">ref-FILES.html</xsl:when>
      <xsl:when test="$gi='fLib'">ref-FLIB.html</xsl:when>
      <xsl:when test="$gi='foreign'">ref-FOREIGN.html</xsl:when>
      <xsl:when test="$gi='foreName'">ref-FORENAME.html</xsl:when>
      <xsl:when test="$gi='forest'">ref-FOREST.html</xsl:when>
      <xsl:when test="$gi='forestGrp'">ref-FORESTGP.html</xsl:when>
      <xsl:when test="$gi='form'">ref-FORM.html</xsl:when>
      <xsl:when test="$gi='formula'">ref-FORMULA.html</xsl:when>
      <xsl:when test="$gi='front'">ref-FRONT.html</xsl:when>
      <xsl:when test="$gi='firstLang'">ref-FRSTLANG.html</xsl:when>
      <xsl:when test="$gi='fsConstraints'">ref-FSCONSTR.html</xsl:when>
      <xsl:when test="$gi='fsdDecl'">ref-FSDDECL.html</xsl:when>
      <xsl:when test="$gi='fsDecl'">ref-FSDECL.html</xsl:when>
      <xsl:when test="$gi='fsDescr'">ref-FSDESCR.html</xsl:when>
      <xsl:when test="$gi='fsLib'">ref-FSLIB.html</xsl:when>
      <xsl:when test="$gi='fs'">ref-FSTAG.html</xsl:when>
      <xsl:when test="$gi='funder'">ref-FUNDER.html</xsl:when>
      <xsl:when test="$gi='fvLib'">ref-FVLIB.html</xsl:when>
      <xsl:when test="$gi='fw'">ref-FW.html</xsl:when>
      <xsl:when test="$gi='gap'">ref-GAP.html</xsl:when>
      <xsl:when test="$gi='gen'">ref-GEN.html</xsl:when>
      <xsl:when test="$gi='genName'">ref-GENNAME.html</xsl:when>
      <xsl:when test="$gi='geog'">ref-GEOG.html</xsl:when>
      <xsl:when test="$gi='geogName'">ref-GEOGNAME.html</xsl:when>
      <xsl:when test="$gi='gi'">ref-GI.html</xsl:when>
      <xsl:when test="$gi='gloss'">ref-GLOSS.html</xsl:when>
      <xsl:when test="$gi='gram'">ref-GRAM.html</xsl:when>
      <xsl:when test="$gi='gramGrp'">ref-GRAMGRP.html</xsl:when>
      <xsl:when test="$gi='graph'">ref-GRAPH.html</xsl:when>
      <xsl:when test="$gi='group'">ref-GROUP.html</xsl:when>
      <xsl:when test="$gi='hand'">ref-HAND.html</xsl:when>
      <xsl:when test="$gi='handList'">ref-HANDLIST.html</xsl:when>
      <xsl:when test="$gi='handShift'">ref-HANDSHFT.html</xsl:when>
      <xsl:when test="$gi='head'">ref-HEAD.html</xsl:when>
      <xsl:when test="$gi='headItem'">ref-HEADIT.html</xsl:when>
      <xsl:when test="$gi='headLabel'">ref-HEADLAB.html</xsl:when>
      <xsl:when test="$gi='hi'">ref-HI.html</xsl:when>
      <xsl:when test="$gi='hom'">ref-HOM.html</xsl:when>
      <xsl:when test="$gi='hour'">ref-HOUR.html</xsl:when>
      <xsl:when test="$gi='hyph'">ref-HYPH.html</xsl:when>
      <xsl:when test="$gi='hyphenation'">ref-HYPHEN.html</xsl:when>
      <xsl:when test="$gi='idno'">ref-IDNO.html</xsl:when>
      <xsl:when test="$gi='if'">ref-IF.html</xsl:when>
      <xsl:when test="$gi='iff'">ref-IFF.html</xsl:when>
      <xsl:when test="$gi='ihs'">ref-IHS.html</xsl:when>
      <xsl:when test="$gi='imprimatur'">ref-IMPRIMAT.html</xsl:when>
      <xsl:when test="$gi='imprint'">ref-IMPRINT.html</xsl:when>
      <xsl:when test="$gi='index'">ref-INDEX.html</xsl:when>
      <xsl:when test="$gi='iNode'">ref-INODE.html</xsl:when>
      <xsl:when test="$gi='interaction'">ref-INTERACT.html</xsl:when>
      <xsl:when test="$gi='interp'">ref-INTERP.html</xsl:when>
      <xsl:when test="$gi='interpGrp'">ref-INTERPGP.html</xsl:when>
      <xsl:when test="$gi='interpretation'">ref-INTERPTN.html</xsl:when>
      <xsl:when test="$gi='item'">ref-ITEM.html</xsl:when>
      <xsl:when test="$gi='itype'">ref-ITYPE.html</xsl:when>
      <xsl:when test="$gi='join'">ref-JOIN.html</xsl:when>
      <xsl:when test="$gi='joinGrp'">ref-JOINGRP.html</xsl:when>
      <xsl:when test="$gi='keywords'">ref-KEYWORDS.html</xsl:when>
      <xsl:when test="$gi='kinesic'">ref-KINESIC.html</xsl:when>
      <xsl:when test="$gi='l'">ref-L.html</xsl:when>
      <xsl:when test="$gi='label'">ref-LABEL.html</xsl:when>
      <xsl:when test="$gi='lacunaEnd'">ref-LACEND.html</xsl:when>
      <xsl:when test="$gi='lacunaStart'">ref-LACSTART.html</xsl:when>
      <xsl:when test="$gi='lang'">ref-LANG.html</xsl:when>
      <xsl:when test="$gi='langKnown'">ref-LANGKNOW.html</xsl:when>
      <xsl:when test="$gi='language'">ref-LANGUAGE.html</xsl:when>
      <xsl:when test="$gi='langUsage'">ref-LANGUSG.html</xsl:when>
      <xsl:when test="$gi='lbl'">ref-LBL.html</xsl:when>
      <xsl:when test="$gi='leaf'">ref-LEAF.html</xsl:when>
      <xsl:when test="$gi='lem'">ref-LEM.html</xsl:when>
      <xsl:when test="$gi='lg'">ref-LG.html</xsl:when>
      <xsl:when test="$gi='lg1'">ref-LG1.html</xsl:when>
      <xsl:when test="$gi='lg2'">ref-LG2.html</xsl:when>
      <xsl:when test="$gi='lg3'">ref-LG3.html</xsl:when>
      <xsl:when test="$gi='lg4'">ref-LG4.html</xsl:when>
      <xsl:when test="$gi='lg5'">ref-LG5.html</xsl:when>
      <xsl:when test="$gi='lb'">ref-LINEBR.html</xsl:when>
      <xsl:when test="$gi='link'">ref-LINK.html</xsl:when>
      <xsl:when test="$gi='linkGrp'">ref-LINKGRP.html</xsl:when>
      <xsl:when test="$gi='list'">ref-LIST.html</xsl:when>
      <xsl:when test="$gi='listBibl'">ref-LISTBIBL.html</xsl:when>
      <xsl:when test="$gi='locale'">ref-LOCALE.html</xsl:when>
      <xsl:when test="$gi='m'">ref-M.html</xsl:when>
      <xsl:when test="$gi='measure'">ref-MEASURE.html</xsl:when>
      <xsl:when test="$gi='meeting'">ref-MEETING.html</xsl:when>
      <xsl:when test="$gi='mentioned'">ref-MENTIOND.html</xsl:when>
      <xsl:when test="$gi='metDecl'">ref-METDECL.html</xsl:when>
      <xsl:when test="$gi='milestone'">ref-MILEST.html</xsl:when>
      <xsl:when test="$gi='minus'">ref-MINUS.html</xsl:when>
      <xsl:when test="$gi='minute'">ref-MINUTE.html</xsl:when>
      <xsl:when test="$gi='monogr'">ref-MONOGR.html</xsl:when>
      <xsl:when test="$gi='month'">ref-MONTH.html</xsl:when>
      <xsl:when test="$gi='mood'">ref-MOOD.html</xsl:when>
      <xsl:when test="$gi='move'">ref-MOVE.html</xsl:when>
      <xsl:when test="$gi='msr'">ref-MSR.html</xsl:when>
      <xsl:when test="$gi='name'">ref-NAME.html</xsl:when>
      <xsl:when test="$gi='nameLink'">ref-NAMELINK.html</xsl:when>
      <xsl:when test="$gi='nbr'">ref-NBR.html</xsl:when>
      <xsl:when test="$gi='node'">ref-NODE.html</xsl:when>
      <xsl:when test="$gi='none'">ref-NONE.html</xsl:when>
      <xsl:when test="$gi='normalization'">ref-NORMALZN.html</xsl:when>
      <xsl:when test="$gi='note'">ref-NOTE.html</xsl:when>
      <xsl:when test="$gi='notesStmt'">ref-NOTSTMT.html</xsl:when>
      <xsl:when test="$gi='null'">ref-NULL.html</xsl:when>
      <xsl:when test="$gi='num'">ref-NUM.html</xsl:when>
      <xsl:when test="$gi='number'">ref-NUMBER.html</xsl:when>
      <xsl:when test="$gi='occasion'">ref-OCCASION.html</xsl:when>
      <xsl:when test="$gi='occupation'">ref-OCCUPAT.html</xsl:when>
      <xsl:when test="$gi='offset'">ref-OFFSET.html</xsl:when>
      <xsl:when test="$gi='ofig'">ref-OFIG.html</xsl:when>
      <xsl:when test="$gi='opener'">ref-OPENER.html</xsl:when>
      <xsl:when test="$gi='oRef'">ref-OREF.html</xsl:when>
      <xsl:when test="$gi='orgDivn'">ref-ORGDIVN.html</xsl:when>
      <xsl:when test="$gi='orgName'">ref-ORGNAME.html</xsl:when>
      <xsl:when test="$gi='orgTitle'">ref-ORGTITLE.html</xsl:when>
      <xsl:when test="$gi='orgType'">ref-ORGTYPE.html</xsl:when>
      <xsl:when test="$gi='orig'">ref-ORIG.html</xsl:when>
      <xsl:when test="$gi='orth'">ref-ORTH.html</xsl:when>
      <xsl:when test="$gi='otherForm'">ref-OTHFORM.html</xsl:when>
      <xsl:when test="$gi='oVar'">ref-OVAR.html</xsl:when>
      <xsl:when test="$gi='p'">ref-P.html</xsl:when>
      <xsl:when test="$gi='pb'">ref-PAGEBR.html</xsl:when>
      <xsl:when test="$gi='parents'">ref-PARENTS.html</xsl:when>
      <xsl:when test="$gi='part'">ref-PART.html</xsl:when>
      <xsl:when test="$gi='particDesc'">ref-PARTDESC.html</xsl:when>
      <xsl:when test="$gi='particLinks'">ref-PARTIREL.html</xsl:when>
      <xsl:when test="$gi='pause'">ref-PAUSE.html</xsl:when>
      <xsl:when test="$gi='per'">ref-PER.html</xsl:when>
      <xsl:when test="$gi='performance'">ref-PERFORM.html</xsl:when>
      <xsl:when test="$gi='personGrp'">ref-PERSGRP.html</xsl:when>
      <xsl:when test="$gi='persName'">ref-PERSNAME.html</xsl:when>
      <xsl:when test="$gi='person'">ref-PERSON.html</xsl:when>
      <xsl:when test="$gi='phr'">ref-PHR.html</xsl:when>
      <xsl:when test="$gi='placeName'">ref-PLACNAME.html</xsl:when>
      <xsl:when test="$gi='col'">ref-PLCOL.html</xsl:when>
      <xsl:when test="$gi='line'">ref-PLLINE.html</xsl:when>
      <xsl:when test="$gi='page'">ref-PLPAGE.html</xsl:when>
      <xsl:when test="$gi='plus'">ref-PLUS.html</xsl:when>
      <xsl:when test="$gi='vol'">ref-PLVOL.html</xsl:when>
      <xsl:when test="$gi='pos'">ref-POS.html</xsl:when>
      <xsl:when test="$gi='postBox'">ref-POSTBOX.html</xsl:when>
      <xsl:when test="$gi='postCode'">ref-POSTCODE.html</xsl:when>
      <xsl:when test="$gi='pRef'">ref-PREF.html</xsl:when>
      <xsl:when test="$gi='preparedness'">ref-PREPNESS.html</xsl:when>
      <xsl:when test="$gi='principal'">ref-PRINCIPL.html</xsl:when>
      <xsl:when test="$gi='profileDesc'">ref-PROFDESC.html</xsl:when>
      <xsl:when test="$gi='projectDesc'">ref-PROJDESC.html</xsl:when>
      <xsl:when test="$gi='prologue'">ref-PROLOGUE.html</xsl:when>
      <xsl:when test="$gi='pron'">ref-PRON.html</xsl:when>
      <xsl:when test="$gi='ptr'">ref-PTR.html</xsl:when>
      <xsl:when test="$gi='publisher'">ref-PUBLISHR.html</xsl:when>
      <xsl:when test="$gi='pubPlace'">ref-PUBPLACE.html</xsl:when>
      <xsl:when test="$gi='publicationStmt'">ref-PUBSTMT.html</xsl:when>
      <xsl:when test="$gi='purpose'">ref-PURPOSE.html</xsl:when>
      <xsl:when test="$gi='pVar'">ref-PVAR.html</xsl:when>
      <xsl:when test="$gi='q'">ref-Q.html</xsl:when>
      <xsl:when test="$gi='quote'">ref-QUOTE.html</xsl:when>
      <xsl:when test="$gi='quotation'">ref-QUOTN.html</xsl:when>
      <xsl:when test="$gi='rate'">ref-RATE.html</xsl:when>
      <xsl:when test="$gi='rdg'">ref-RDG.html</xsl:when>
      <xsl:when test="$gi='rdgGrp'">ref-RDGGRP.html</xsl:when>
      <xsl:when test="$gi='re'">ref-RE.html</xsl:when>
      <xsl:when test="$gi='recording'">ref-RECORDIN.html</xsl:when>
      <xsl:when test="$gi='recordingStmt'">ref-RECSTMT.html</xsl:when>
      <xsl:when test="$gi='ref'">ref-REF.html</xsl:when>
      <xsl:when test="$gi='refsDecl'">ref-REFSDECL.html</xsl:when>
      <xsl:when test="$gi='reg'">ref-REG.html</xsl:when>
      <xsl:when test="$gi='region'">ref-REGION.html</xsl:when>
      <xsl:when test="$gi='relation'">ref-RELATION.html</xsl:when>
      <xsl:when test="$gi='remarks'">ref-REMARKS.html</xsl:when>
      <xsl:when test="$gi='rendition'">ref-RENDITN.html</xsl:when>
      <xsl:when test="$gi='residence'">ref-RESIDENC.html</xsl:when>
      <xsl:when test="$gi='respStmt'">ref-RESP.html</xsl:when>
      <xsl:when test="$gi='respons'">ref-RESPONS.html</xsl:when>
      <xsl:when test="$gi='restore'">ref-RESTORE.html</xsl:when>
      <xsl:when test="$gi='revisionDesc'">ref-REVDESC.html</xsl:when>
      <xsl:when test="$gi='resp'">ref-ROLE.html</xsl:when>
      <xsl:when test="$gi='roleDesc'">ref-ROLEDESC.html</xsl:when>
      <xsl:when test="$gi='roleName'">ref-ROLENAME.html</xsl:when>
      <xsl:when test="$gi='root'">ref-ROOT.html</xsl:when>
      <xsl:when test="$gi='row'">ref-ROW.html</xsl:when>
      <xsl:when test="$gi='rs'">ref-RS.html</xsl:when>
      <xsl:when test="$gi='s'">ref-S.html</xsl:when>
      <xsl:when test="$gi='salute'">ref-SALUTE.html</xsl:when>
      <xsl:when test="$gi='samplingDecl'">ref-SAMPDECL.html</xsl:when>
      <xsl:when test="$gi='script'">ref-SCRIPT.html</xsl:when>
      <xsl:when test="$gi='scriptStmt'">ref-SCRSTMT.html</xsl:when>
      <xsl:when test="$gi='second'">ref-SECOND.html</xsl:when>
      <xsl:when test="$gi='seg'">ref-SEG.html</xsl:when>
      <xsl:when test="$gi='segmentation'">ref-SEGMENTN.html</xsl:when>
      <xsl:when test="$gi='sense'">ref-SENSE.html</xsl:when>
      <xsl:when test="$gi='series'">ref-SERIES.html</xsl:when>
      <xsl:when test="$gi='seriesStmt'">ref-SERSTMT.html</xsl:when>
      <xsl:when test="$gi='set'">ref-SET.html</xsl:when>
      <xsl:when test="$gi='settingDesc'">ref-SETTDESC.html</xsl:when>
      <xsl:when test="$gi='setting'">ref-SETTING.html</xsl:when>
      <xsl:when test="$gi='settlement'">ref-SETTLE.html</xsl:when>
      <xsl:when test="$gi='shift'">ref-SHIFT.html</xsl:when>
      <xsl:when test="$gi='sic'">ref-SIC.html</xsl:when>
      <xsl:when test="$gi='signed'">ref-SIGNED.html</xsl:when>
      <xsl:when test="$gi='soCalled'">ref-SOCALLED.html</xsl:when>
      <xsl:when test="$gi='socecStatus'">ref-SOCECSTA.html</xsl:when>
      <xsl:when test="$gi='sound'">ref-SOUND.html</xsl:when>
      <xsl:when test="$gi='sourceDesc'">ref-SOUSTMT.html</xsl:when>
      <xsl:when test="$gi='sp'">ref-SP.html</xsl:when>
      <xsl:when test="$gi='space'">ref-SPACE.html</xsl:when>
      <xsl:when test="$gi='span'">ref-SPAN.html</xsl:when>
      <xsl:when test="$gi='spanGrp'">ref-SPANGRP.html</xsl:when>
      <xsl:when test="$gi='speaker'">ref-SPEAKER.html</xsl:when>
      <xsl:when test="$gi='sponsor'">ref-SPONSOR.html</xsl:when>
      <xsl:when test="$gi='stage'">ref-STAGE.html</xsl:when>
      <xsl:when test="$gi='state'">ref-STATE.html</xsl:when>
      <xsl:when test="$gi='stdVals'">ref-STDVALS.html</xsl:when>
      <xsl:when test="$gi='step'">ref-STEP.html</xsl:when>
      <xsl:when test="$gi='str'">ref-STR.html</xsl:when>
      <xsl:when test="$gi='street'">ref-STREET.html</xsl:when>
      <xsl:when test="$gi='stress'">ref-STRESS.html</xsl:when>
      <xsl:when test="$gi='string'">ref-STRING.html</xsl:when>
      <xsl:when test="$gi='subc'">ref-SUBC.html</xsl:when>
      <xsl:when test="$gi='superEntry'">ref-SUPENTRY.html</xsl:when>
      <xsl:when test="$gi='supplied'">ref-SUPPLIED.html</xsl:when>
      <xsl:when test="$gi='surname'">ref-SURNAME.html</xsl:when>
      <xsl:when test="$gi='syll'">ref-SYLL.html</xsl:when>
      <xsl:when test="$gi='sym'">ref-SYM.html</xsl:when>
      <xsl:when test="$gi='symbol'">ref-SYMBOL.html</xsl:when>
      <xsl:when test="$gi='table'">ref-TABLE.html</xsl:when>
      <xsl:when test="$gi='tag'">ref-TAG.html</xsl:when>
      <xsl:when test="$gi='tagDoc'">ref-TAGDOC.html</xsl:when>
      <xsl:when test="$gi='tagsDecl'">ref-TAGSDECL.html</xsl:when>
      <xsl:when test="$gi='tagUsage'">ref-TAGUSAGE.html</xsl:when>
      <xsl:when test="$gi='taxonomy'">ref-TAXONOMY.html</xsl:when>
      <xsl:when test="$gi='egTD'">ref-TDEG.html</xsl:when>
      <xsl:when test="$gi='tech'">ref-TECH.html</xsl:when>
      <xsl:when test="$gi='TEI.2'">ref-TEI2.html</xsl:when>
      <xsl:when test="$gi='teiCorpus.2'">ref-TEICORP2.html</xsl:when>
      <xsl:when test="$gi='teiFsd2'">ref-TEIFSD2.html</xsl:when>
      <xsl:when test="$gi='teiHeader'">ref-TEIHEAD.html</xsl:when>
      <xsl:when test="$gi='writingSystemDeclaration'">ref-TEIWSD.html</xsl:when>
      <xsl:when test="$gi='term'">ref-TERM.html</xsl:when>
      <xsl:when test="$gi='termEntryF'">ref-TERMENTF.html</xsl:when>
      <xsl:when test="$gi='termEntryN'">ref-TERMENTN.html</xsl:when>
      <xsl:when test="$gi='text'">ref-TEXT.html</xsl:when>
      <xsl:when test="$gi='textClass'">ref-TEXTCLAS.html</xsl:when>
      <xsl:when test="$gi='textDesc'">ref-TEXTDESC.html</xsl:when>
      <xsl:when test="$gi='then'">ref-THEN.html</xsl:when>
      <xsl:when test="$gi='tig'">ref-TIG.html</xsl:when>
      <xsl:when test="$gi='time'">ref-TIME.html</xsl:when>
      <xsl:when test="$gi='timeline'">ref-TIMELINE.html</xsl:when>
      <xsl:when test="$gi='timeRange'">ref-TIMERANG.html</xsl:when>
      <xsl:when test="$gi='timeStruct'">ref-TIMESTRU.html</xsl:when>
      <xsl:when test="$gi='title'">ref-TITLE.html</xsl:when>
      <xsl:when test="$gi='titlePage'">ref-TITLEPA.html</xsl:when>
      <xsl:when test="$gi='titlePart'">ref-TITLEPT.html</xsl:when>
      <xsl:when test="$gi='titleStmt'">ref-TITSTMT.html</xsl:when>
      <xsl:when test="$gi='tns'">ref-TNS.html</xsl:when>
      <xsl:when test="$gi='tr'">ref-TR.html</xsl:when>
      <xsl:when test="$gi='trailer'">ref-TRAILER.html</xsl:when>
      <xsl:when test="$gi='trans'">ref-TRANS.html</xsl:when>
      <xsl:when test="$gi='tree'">ref-TREE.html</xsl:when>
      <xsl:when test="$gi='triangle'">ref-TRIANGLE.html</xsl:when>
      <xsl:when test="$gi='tsd'">ref-TSD.html</xsl:when>
      <xsl:when test="$gi='u'">ref-U.html</xsl:when>
      <xsl:when test="$gi='uncertain'">ref-UNCERT.html</xsl:when>
      <xsl:when test="$gi='unclear'">ref-UNCLEAR.html</xsl:when>
      <xsl:when test="$gi='usg'">ref-USG.html</xsl:when>
      <xsl:when test="$gi='val'">ref-VAL.html</xsl:when>
      <xsl:when test="$gi='valDesc'">ref-VALDESC.html</xsl:when>
      <xsl:when test="$gi='valList'">ref-VALLIST.html</xsl:when>
      <xsl:when test="$gi='vAlt'">ref-VALT.html</xsl:when>
      <xsl:when test="$gi='variantEncoding'">ref-VARENCOD.html</xsl:when>
      <xsl:when test="$gi='vDefault'">ref-VDFT.html</xsl:when>
      <xsl:when test="$gi='version'">ref-VERNAME.html</xsl:when>
      <xsl:when test="$gi='view'">ref-VIEW.html</xsl:when>
      <xsl:when test="$gi='vocal'">ref-VOCAL.html</xsl:when>
      <xsl:when test="$gi='vRange'">ref-VRANGE.html</xsl:when>
      <xsl:when test="$gi='w'">ref-W.html</xsl:when>
      <xsl:when test="$gi='week'">ref-WEEK.html</xsl:when>
      <xsl:when test="$gi='when'">ref-WHEN.html</xsl:when>
      <xsl:when test="$gi='wit'">ref-WIT.html</xsl:when>
      <xsl:when test="$gi='witDetail'">ref-WITDTL.html</xsl:when>
      <xsl:when test="$gi='witEnd'">ref-WITEND.html</xsl:when>
      <xsl:when test="$gi='witList'">ref-WITLIST.html</xsl:when>
      <xsl:when test="$gi='witness'">ref-WITNESS.html</xsl:when>
      <xsl:when test="$gi='witStart'">ref-WITSTART.html</xsl:when>
      <xsl:when test="$gi='writing'">ref-WRITING.html</xsl:when>
      <xsl:when test="$gi='codedCharSet'">ref-WSDCCS.html</xsl:when>
      <xsl:when test="$gi='character'">ref-WSDCHAR.html</xsl:when>
      <xsl:when test="$gi='characters'">ref-WSDCHARS.html</xsl:when>
      <xsl:when test="$gi='desc'">ref-WSDDESC.html</xsl:when>
      <xsl:when test="$gi='entitySet'">ref-WSDENTS.html</xsl:when>
      <xsl:when test="$gi='figure'">ref-WSDFIG.html</xsl:when>
      <xsl:when test="$gi='form'">ref-WSDFORM.html</xsl:when>
      <xsl:when test="$gi='languageWSD'">ref-WSDLANG.html</xsl:when>
      <xsl:when test="$gi='noteWSD'">ref-WSDNOTE.html</xsl:when>
      <xsl:when test="$gi='extFigure'">ref-WSDXFIG.html</xsl:when>
      <xsl:when test="$gi='xptr'">ref-XPTR.html</xsl:when>
      <xsl:when test="$gi='xr'">ref-XR.html</xsl:when>
      <xsl:when test="$gi='xref'">ref-XREF.html</xsl:when>
      <xsl:when test="$gi='year'">ref-YEAR.html</xsl:when>
    </xsl:choose>
  </xsl:template>

  <!-- I18N -->
  <xsl:param name="LABELATT-type">
    <xsl:choose>
      <xsl:when test="$lang = 'en'">type</xsl:when>
      <xsl:when test="$lang = 'sl'">tip</xsl:when>
    </xsl:choose>
  </xsl:param>
  <xsl:param name="LABELATT-lang">
    <xsl:choose>
      <xsl:when test="$lang = 'en'">language</xsl:when>
      <xsl:when test="$lang = 'sl'">jezik</xsl:when>
    </xsl:choose>
  </xsl:param>
  <xsl:param name="LABELATT-creator">
    <xsl:choose>
      <xsl:when test="$lang = 'en'">created</xsl:when>
      <xsl:when test="$lang = 'sl'">zapisal</xsl:when>
    </xsl:choose>
  </xsl:param>
  <xsl:param name="LABELATT-date">
    <xsl:choose>
      <xsl:when test="$lang = 'en'">date</xsl:when>
      <xsl:when test="$lang = 'sl'">datum</xsl:when>
    </xsl:choose>
  </xsl:param>
  <xsl:param name="LABELATT-date.created">
    <xsl:choose>
      <xsl:when test="$lang = 'en'">created</xsl:when>
      <xsl:when test="$lang = 'sl'">napisano</xsl:when>
    </xsl:choose>
  </xsl:param>
  <xsl:param name="LABELATT-date.updated">
    <xsl:choose>
      <xsl:when test="$lang = 'en'">updated</xsl:when>
      <xsl:when test="$lang = 'sl'">popravljeno</xsl:when>
    </xsl:choose>
  </xsl:param>


  <xsl:param name="LABEL-teiHeader">
    <A>
      <xsl:attribute name="href">
        <xsl:call-template name="teip4-elts">
          <xsl:with-param name="gi">teiHeader</xsl:with-param>
        </xsl:call-template>
      </xsl:attribute>
      <xsl:choose>
        <xsl:when test="$lang = 'en'">TEI Header</xsl:when>
        <xsl:when test="$lang = 'sl'">Kolofon TEI</xsl:when>
      </xsl:choose>
    </A>
  </xsl:param>
  <xsl:param name="LABEL-fileDesc">
    <A>
      <xsl:attribute name="href">
        <xsl:call-template name="teip4-elts">
          <xsl:with-param name="gi">fileDesc</xsl:with-param>
        </xsl:call-template>
      </xsl:attribute>
      <xsl:choose>
        <xsl:when test="$lang = 'en'">File Description</xsl:when>
        <xsl:when test="$lang = 'sl'">Opis datoteke</xsl:when>
      </xsl:choose>
    </A>
  </xsl:param>
  <xsl:param name="LABEL-sourceDesc">
    <A>
      <xsl:attribute name="href">
        <xsl:call-template name="teip4-elts">
          <xsl:with-param name="gi">sourceDesc</xsl:with-param>
        </xsl:call-template>
      </xsl:attribute>
      <xsl:choose>
        <xsl:when test="$lang = 'en'">Source Description</xsl:when>
        <xsl:when test="$lang = 'sl'">Opis vira</xsl:when>
      </xsl:choose>
    </A>
  </xsl:param>
  <xsl:param name="LABEL-encodingDesc">
    <A>
      <xsl:attribute name="href">
        <xsl:call-template name="teip4-elts">
          <xsl:with-param name="gi">encodingDesc</xsl:with-param>
        </xsl:call-template>
      </xsl:attribute>
      <xsl:choose>
        <xsl:when test="$lang = 'en'">Encoding Description</xsl:when>
        <xsl:when test="$lang = 'sl'">Opis zapisa</xsl:when>
      </xsl:choose>
    </A>
  </xsl:param>
  <xsl:param name="LABEL-projectDesc">
    <A>
      <xsl:attribute name="href">
        <xsl:call-template name="teip4-elts">
          <xsl:with-param name="gi">projectDesc</xsl:with-param>
        </xsl:call-template>
      </xsl:attribute>
      <xsl:choose>
        <xsl:when test="$lang = 'en'">Project description</xsl:when>
        <xsl:when test="$lang = 'sl'">Opis projekta</xsl:when>
      </xsl:choose>
    </A>
  </xsl:param>
  <xsl:param name="LABEL-variantEncoding">
    <A>
      <xsl:attribute name="href">
        <xsl:call-template name="teip4-elts">
          <xsl:with-param name="gi">variantEncoding</xsl:with-param>
        </xsl:call-template>
      </xsl:attribute>
      <xsl:choose>
        <xsl:when test="$lang = 'en'">Variant Encoding</xsl:when>
        <xsl:when test="$lang = 'sl'">Zapis variant</xsl:when>
      </xsl:choose>
    </A>
  </xsl:param>
  <xsl:param name="LABEL-profileDesc">
    <A>
      <xsl:attribute name="href">
        <xsl:call-template name="teip4-elts">
          <xsl:with-param name="gi">profileDesc</xsl:with-param>
        </xsl:call-template>
      </xsl:attribute>
      <xsl:choose>
        <xsl:when test="$lang = 'en'">Profile Description</xsl:when>
        <xsl:when test="$lang = 'sl'">Opis karakteristik</xsl:when>
      </xsl:choose>
    </A>
  </xsl:param>
  <xsl:param name="LABEL-revisionDesc">
    <A>
      <xsl:attribute name="href">
        <xsl:call-template name="teip4-elts">
          <xsl:with-param name="gi">revisionDesc</xsl:with-param>
        </xsl:call-template>
      </xsl:attribute>
      <xsl:choose>
        <xsl:when test="$lang = 'en'">Revision Description</xsl:when>
        <xsl:when test="$lang = 'sl'">Opis sprememb</xsl:when>
      </xsl:choose>
    </A>
  </xsl:param>
  <xsl:param name="LABEL-titleStmt">
    <A>
      <xsl:attribute name="href">
        <xsl:call-template name="teip4-elts">
          <xsl:with-param name="gi">titleStmt</xsl:with-param>
        </xsl:call-template>
      </xsl:attribute>
      <xsl:choose>
        <xsl:when test="$lang = 'en'">Title Statement</xsl:when>
        <xsl:when test="$lang = 'sl'">Naslovna izjava</xsl:when>
      </xsl:choose>
    </A>
  </xsl:param>
  <xsl:param name="LABEL-publicationStmt">
    <A>
      <xsl:attribute name="href">
        <xsl:call-template name="teip4-elts">
          <xsl:with-param name="gi">publicationStmt</xsl:with-param>
        </xsl:call-template>
      </xsl:attribute>
      <xsl:choose>
        <xsl:when test="$lang = 'en'">Publication Statement</xsl:when>
        <xsl:when test="$lang = 'sl'">Izjava o objavi</xsl:when>
      </xsl:choose>
    </A>
  </xsl:param>
  <xsl:param name="LABEL-notesStmt">
    <A>
      <xsl:attribute name="href">
        <xsl:call-template name="teip4-elts">
          <xsl:with-param name="gi">notesStmt</xsl:with-param>
        </xsl:call-template>
      </xsl:attribute>
      <xsl:choose>
        <xsl:when test="$lang = 'en'">Notes Statement</xsl:when>
        <xsl:when test="$lang = 'sl'">Dodatne opombe</xsl:when>
      </xsl:choose>
    </A>
  </xsl:param>
  <xsl:param name="LABEL-respStmt">
    <A>
      <xsl:attribute name="href">
        <xsl:call-template name="teip4-elts">
          <xsl:with-param name="gi">respStmt</xsl:with-param>
        </xsl:call-template>
      </xsl:attribute>
      <xsl:choose>
        <xsl:when test="$lang = 'en'">Responsibility Statement</xsl:when>
        <xsl:when test="$lang = 'sl'">Izjava o odgovornosti</xsl:when>
      </xsl:choose>
    </A>
  </xsl:param>
  <xsl:param name="LABEL-editionStmt">
    <A>
      <xsl:attribute name="href">
        <xsl:call-template name="teip4-elts">
          <xsl:with-param name="gi">editionStmt</xsl:with-param>
        </xsl:call-template>
      </xsl:attribute>
      <xsl:choose>
        <xsl:when test="$lang = 'en'">Edition Statement</xsl:when>
        <xsl:when test="$lang = 'sl'">Izjava o ediciji</xsl:when>
      </xsl:choose>
    </A>
  </xsl:param>
  <xsl:param name="LABEL-editorialDecl">
    <A>
      <xsl:attribute name="href">
        <xsl:call-template name="teip4-elts">
          <xsl:with-param name="gi">editorialDecl</xsl:with-param>
        </xsl:call-template>
      </xsl:attribute>
      <xsl:choose>
        <xsl:when test="$lang = 'en'">Editorial declaration</xsl:when>
        <xsl:when test="$lang = 'sl'">Uredni&#353;ka deklaracija</xsl:when>
      </xsl:choose>
    </A>
  </xsl:param>
  <!-- USER EXTENSION a la P5 -->
  <xsl:param name="LABEL-charDesc">
    <A href="http://www.tei-c.org/P5/Guidelines/ref-charDesc.html">
      <xsl:choose>
        <xsl:when test="$lang = 'en'">Character description</xsl:when>
        <xsl:when test="$lang = 'sl'">Opis znakov</xsl:when>
      </xsl:choose>
    </A>
  </xsl:param>
  <xsl:param name="LABEL-tagsDecl">
    <A>
      <xsl:attribute name="href">
        <xsl:call-template name="teip4-elts">
          <xsl:with-param name="gi">tagsDecl</xsl:with-param>
        </xsl:call-template>
      </xsl:attribute>
      <xsl:choose>
        <xsl:when test="$lang = 'en'">Tags declaration</xsl:when>
        <xsl:when test="$lang = 'sl'">Deklaracija o oznakah</xsl:when>
      </xsl:choose>
    </A>
  </xsl:param>
  <xsl:param name="LABEL-classDecl">
    <A>
      <xsl:attribute name="href">
        <xsl:call-template name="teip4-elts">
          <xsl:with-param name="gi">classDecl</xsl:with-param>
        </xsl:call-template>
      </xsl:attribute>
      <xsl:choose>
        <xsl:when test="$lang = 'en'">Class declaration</xsl:when>
        <xsl:when test="$lang = 'sl'">Deklaracija o razredih</xsl:when>
      </xsl:choose>
    </A>
  </xsl:param>
  <xsl:param name="LABEL-fsDecl">
    <A>
      <xsl:attribute name="href">
        <xsl:call-template name="teip4-elts">
          <xsl:with-param name="gi">fsDecl</xsl:with-param>
        </xsl:call-template>
      </xsl:attribute>
      <xsl:choose>
        <xsl:when test="$lang = 'en'">Feature-structure declaration</xsl:when>
        <xsl:when test="$lang = 'sl'">Deklaracija lastnostnih strukturah</xsl:when>
      </xsl:choose>
    </A>
  </xsl:param>
  <xsl:param name="LABEL-fsdDecl">
    <A>
      <xsl:attribute name="href">
        <xsl:call-template name="teip4-elts">
          <xsl:with-param name="gi">fsdDecl</xsl:with-param>
        </xsl:call-template>
      </xsl:attribute>
      <xsl:choose>
        <xsl:when test="$lang = 'en'">Feature-system declaration</xsl:when>
        <xsl:when test="$lang = 'sl'">Deklaracija sistema lastnostnih struktur</xsl:when>
      </xsl:choose>
    </A>
  </xsl:param>
  <xsl:param name="LABEL-flib">
    <A>
      <xsl:attribute name="href">
        <xsl:call-template name="teip4-elts">
          <xsl:with-param name="gi">flib</xsl:with-param>
        </xsl:call-template>
      </xsl:attribute>
      <xsl:choose>
        <xsl:when test="$lang = 'en'">Feature library</xsl:when>
        <xsl:when test="$lang = 'sl'">Knji&#x17E;nica lastnosti</xsl:when>
      </xsl:choose>
    </A>
    <xsl:choose>
      <xsl:when test="$lang = 'en'"> (values not shown)</xsl:when>
      <xsl:when test="$lang = 'sl'"> (vrednosti niso prikazane)</xsl:when>
    </xsl:choose>
  </xsl:param>
  <xsl:param name="LABEL-fslib">
    <A>
      <xsl:attribute name="href">
        <xsl:call-template name="teip4-elts">
          <xsl:with-param name="gi">fslib</xsl:with-param>
        </xsl:call-template>
      </xsl:attribute>
      <xsl:choose>
        <xsl:when test="$lang = 'en'">Feature-structure library</xsl:when>
        <xsl:when test="$lang = 'sl'">Knji&#x17E;nica lastnostnih struktur</xsl:when>
      </xsl:choose>
    </A>
    <xsl:choose>
      <xsl:when test="$lang = 'en'"> (values not shown)</xsl:when>
      <xsl:when test="$lang = 'sl'"> (vrednosti niso prikazane)</xsl:when>
    </xsl:choose>
  </xsl:param>

  <xsl:param name="LABEL-extent">
    <A>
      <xsl:attribute name="href">
        <xsl:call-template name="teip4-elts">
          <xsl:with-param name="gi">extent</xsl:with-param>
        </xsl:call-template>
      </xsl:attribute>
      <xsl:choose>
        <xsl:when test="$lang = 'en'">Extent</xsl:when>
        <xsl:when test="$lang = 'sl'">Obseg</xsl:when>
      </xsl:choose>
    </A>
  </xsl:param>
  <xsl:param name="LABEL-taxonomy">
    <A>
      <xsl:attribute name="href">
        <xsl:call-template name="teip4-elts">
          <xsl:with-param name="gi">taxonomy</xsl:with-param>
        </xsl:call-template>
      </xsl:attribute>
      <xsl:choose>
        <xsl:when test="$lang = 'en'">Taxonomy</xsl:when>
        <xsl:when test="$lang = 'sl'">Taksonomija</xsl:when>
      </xsl:choose>
    </A>
  </xsl:param>
  <xsl:param name="LABEL-category">
    <A>
      <xsl:attribute name="href">
        <xsl:call-template name="teip4-elts">
          <xsl:with-param name="gi">category</xsl:with-param>
        </xsl:call-template>
      </xsl:attribute>
      <xsl:choose>
        <xsl:when test="$lang = 'en'">Category</xsl:when>
        <xsl:when test="$lang = 'sl'">Kategorija</xsl:when>
      </xsl:choose>
    </A>
  </xsl:param>
  <xsl:param name="LABEL-correction">
    <A>
      <xsl:attribute name="href">
        <xsl:call-template name="teip4-elts">
          <xsl:with-param name="gi">correction</xsl:with-param>
        </xsl:call-template>
      </xsl:attribute>
      <xsl:choose>
        <xsl:when test="$lang = 'en'">Correction</xsl:when>
        <xsl:when test="$lang = 'sl'">Popravki</xsl:when>
      </xsl:choose>
    </A>
  </xsl:param>
  <xsl:param name="LABEL-hyphenation">
    <A>
      <xsl:attribute name="href">
        <xsl:call-template name="teip4-elts">
          <xsl:with-param name="gi">hyphenation</xsl:with-param>
        </xsl:call-template>
      </xsl:attribute>
      <xsl:choose>
        <xsl:when test="$lang = 'en'">Hyphenation</xsl:when>
        <xsl:when test="$lang = 'sl'">Deljaji</xsl:when>
      </xsl:choose>
    </A>
  </xsl:param>
  <xsl:param name="LABEL-normalization">
    <A>
      <xsl:attribute name="href">
        <xsl:call-template name="teip4-elts">
          <xsl:with-param name="gi">normalization</xsl:with-param>
        </xsl:call-template>
      </xsl:attribute>
      <xsl:choose>
        <xsl:when test="$lang = 'en'">Normalisation</xsl:when>
        <xsl:when test="$lang = 'sl'">Normalizacija</xsl:when>
      </xsl:choose>
    </A>
  </xsl:param>
  <xsl:param name="LABEL-quotation">
    <A>
      <xsl:attribute name="href">
        <xsl:call-template name="teip4-elts">
          <xsl:with-param name="gi">quotation</xsl:with-param>
        </xsl:call-template>
      </xsl:attribute>
      <xsl:choose>
        <xsl:when test="$lang = 'en'">Quotation</xsl:when>
        <xsl:when test="$lang = 'sl'">Navednice</xsl:when>
      </xsl:choose>
    </A>
  </xsl:param>
  <xsl:param name="LABEL-segmentation">
    <A>
      <xsl:attribute name="href">
        <xsl:call-template name="teip4-elts">
          <xsl:with-param name="gi">segmentation</xsl:with-param>
        </xsl:call-template>
      </xsl:attribute>
      <xsl:choose>
        <xsl:when test="$lang = 'en'">Segmentation</xsl:when>
        <xsl:when test="$lang = 'sl'">Segmentacija</xsl:when>
      </xsl:choose>
    </A>
  </xsl:param>
  <xsl:param name="LABEL-stdVals">
    <A>
      <xsl:attribute name="href">
        <xsl:call-template name="teip4-elts">
          <xsl:with-param name="gi">stdVals</xsl:with-param>
        </xsl:call-template>
      </xsl:attribute>
      <xsl:choose>
        <xsl:when test="$lang = 'en'">Standard values</xsl:when>
        <xsl:when test="$lang = 'sl'">Standardne vrednosti</xsl:when>
      </xsl:choose>
    </A>
  </xsl:param>
  <xsl:param name="LABEL-interpretation">
    <A>
      <xsl:attribute name="href">
        <xsl:call-template name="teip4-elts">
          <xsl:with-param name="gi">interpretation</xsl:with-param>
        </xsl:call-template>
      </xsl:attribute>
      <xsl:choose>
        <xsl:when test="$lang = 'en'">Interpretation</xsl:when>
        <xsl:when test="$lang = 'sl'">Interpretacija</xsl:when>
      </xsl:choose>
    </A>
  </xsl:param>
  <xsl:param name="LABEL-imprint">
    <A>
      <xsl:attribute name="href">
        <xsl:call-template name="teip4-elts">
          <xsl:with-param name="gi">imprint</xsl:with-param>
        </xsl:call-template>
      </xsl:attribute>
      <xsl:choose>
        <xsl:when test="$lang = 'en'">Imprint</xsl:when>
        <xsl:when test="$lang = 'sl'">Impresum</xsl:when>
      </xsl:choose>
    </A>
  </xsl:param>
  <xsl:param name="LABEL-biblScope">
    <A>
      <xsl:attribute name="href">
        <xsl:call-template name="teip4-elts">
          <xsl:with-param name="gi">biblScope</xsl:with-param>
        </xsl:call-template>
      </xsl:attribute>
      <xsl:choose>
        <xsl:when test="$lang = 'en'">Scope of Citation</xsl:when>
        <xsl:when test="$lang = 'sl'">Obseg navedbe</xsl:when>
      </xsl:choose>
    </A>
  </xsl:param>
  <xsl:param name="LABEL-pubPlace">
    <A>
      <xsl:attribute name="href">
        <xsl:call-template name="teip4-elts">
          <xsl:with-param name="gi">pubPlace</xsl:with-param>
        </xsl:call-template>
      </xsl:attribute>
      <xsl:choose>
        <xsl:when test="$lang = 'en'">Place of publication</xsl:when>
        <xsl:when test="$lang = 'sl'">Mesto publikacije</xsl:when>
      </xsl:choose>
    </A>
  </xsl:param>
  <xsl:param name="LABEL-langUsage">
    <A>
      <xsl:attribute name="href">
        <xsl:call-template name="teip4-elts">
          <xsl:with-param name="gi">langUsage</xsl:with-param>
        </xsl:call-template>
      </xsl:attribute>
      <xsl:choose>
        <xsl:when test="$lang = 'en'">Language use</xsl:when>
        <xsl:when test="$lang = 'sl'">Jeziki</xsl:when>
      </xsl:choose>
    </A>
  </xsl:param>
  <xsl:param name="LABEL-handList">
    <A>
      <xsl:attribute name="href">
        <xsl:call-template name="teip4-elts">
          <xsl:with-param name="gi">handList</xsl:with-param>
        </xsl:call-template>
      </xsl:attribute>
      <xsl:choose>
        <xsl:when test="$lang = 'en'">Hand list</xsl:when>
        <xsl:when test="$lang = 'sl'">Seznam rok</xsl:when>
      </xsl:choose>
    </A>
  </xsl:param>
  <xsl:param name="LABEL-bibl">
    <A>
      <xsl:attribute name="href">
        <xsl:call-template name="teip4-elts">
          <xsl:with-param name="gi">bibl</xsl:with-param>
        </xsl:call-template>
      </xsl:attribute>
      <xsl:choose>
        <xsl:when test="$lang = 'en'">Bibliographic item</xsl:when>
        <xsl:when test="$lang = 'sl'">Bibliografska enota</xsl:when>
      </xsl:choose>
    </A>
  </xsl:param>
  <xsl:param name="LABEL-listBibl">
    <A>
      <xsl:attribute name="href">
        <xsl:call-template name="teip4-elts">
          <xsl:with-param name="gi">listBibl</xsl:with-param>
        </xsl:call-template>
      </xsl:attribute>
      <xsl:choose>
        <xsl:when test="$lang = 'en'">Bibliography list</xsl:when>
        <xsl:when test="$lang = 'sl'">Seznam bibliografskih enot</xsl:when>
      </xsl:choose>
    </A>
  </xsl:param>
  <xsl:param name="LABEL-titleStmt-editor">
    <A>
      <xsl:attribute name="href">
        <xsl:call-template name="teip4-elts">
          <xsl:with-param name="gi">editor</xsl:with-param>
        </xsl:call-template>
      </xsl:attribute>
      <xsl:choose>
        <xsl:when test="$lang = 'en'">Editor</xsl:when>
        <xsl:when test="$lang = 'sl'">Urednik</xsl:when>
      </xsl:choose>
    </A>
  </xsl:param>
  <xsl:param name="LABEL-principal">
    <A>
      <xsl:attribute name="href">
        <xsl:call-template name="teip4-elts">
          <xsl:with-param name="gi">principal</xsl:with-param>
        </xsl:call-template>
      </xsl:attribute>
      <xsl:choose>
        <xsl:when test="$lang = 'en'">Principal researcher</xsl:when>
        <xsl:when test="$lang = 'sl'">Nosilec</xsl:when>
      </xsl:choose>
    </A>
  </xsl:param>
  <xsl:param name="LABEL-editor">
    <A>
      <xsl:attribute name="href">
        <xsl:call-template name="teip4-elts">
          <xsl:with-param name="gi">editor</xsl:with-param>
        </xsl:call-template>
      </xsl:attribute>
      <xsl:choose>
        <xsl:when test="$lang = 'en'">(ed.)</xsl:when>
        <xsl:when test="$lang = 'sl'">(ur.)</xsl:when>
      </xsl:choose>
    </A>
  </xsl:param>
  <xsl:param name="LABEL-edition">
    <A>
      <xsl:attribute name="href">
        <xsl:call-template name="teip4-elts">
          <xsl:with-param name="gi">edition</xsl:with-param>
        </xsl:call-template>
      </xsl:attribute>
      <xsl:choose>
        <xsl:when test="$lang = 'en'">Edition</xsl:when>
        <xsl:when test="$lang = 'sl'">Izdaja</xsl:when>
      </xsl:choose>
    </A>
  </xsl:param>
  <xsl:param name="LABEL-monogr">
    <A>
      <xsl:attribute name="href">
        <xsl:call-template name="teip4-elts">
          <xsl:with-param name="gi">monogr</xsl:with-param>
        </xsl:call-template>
      </xsl:attribute>
      <xsl:choose>
        <xsl:when test="$lang = 'en'">Monograph level</xsl:when>
        <xsl:when test="$lang = 'sl'">Monografska raven</xsl:when>
      </xsl:choose>
    </A>
  </xsl:param>
  <xsl:param name="LABEL-analytic">
    <A>
      <xsl:attribute name="href">
        <xsl:call-template name="teip4-elts">
          <xsl:with-param name="gi">analytic</xsl:with-param>
        </xsl:call-template>
      </xsl:attribute>
      <xsl:choose>
        <xsl:when test="$lang = 'en'">Analytic level</xsl:when>
        <xsl:when test="$lang = 'sl'">Ananaliti&#x10D;na raven</xsl:when>
      </xsl:choose>
    </A>
  </xsl:param>
  <xsl:param name="LABEL-note">
    <A>
      <xsl:attribute name="href">
        <xsl:call-template name="teip4-elts">
          <xsl:with-param name="gi">note</xsl:with-param>
        </xsl:call-template>
      </xsl:attribute>
      <xsl:choose>
        <xsl:when test="$lang = 'en'">Note</xsl:when>
        <xsl:when test="$lang = 'sl'">Opomba</xsl:when>
      </xsl:choose>
    </A>
  </xsl:param>
  <xsl:param name="LABEL-address">
    <A>
      <xsl:attribute name="href">
        <xsl:call-template name="teip4-elts">
          <xsl:with-param name="gi">address</xsl:with-param>
        </xsl:call-template>
      </xsl:attribute>
      <xsl:choose>
        <xsl:when test="$lang = 'en'">Address</xsl:when>
        <xsl:when test="$lang = 'sl'">Naslov</xsl:when>
      </xsl:choose>
    </A>
  </xsl:param>
  <xsl:param name="LABEL-availability">
    <A>
      <xsl:attribute name="href">
        <xsl:call-template name="teip4-elts">
          <xsl:with-param name="gi">availability</xsl:with-param>
        </xsl:call-template>
      </xsl:attribute>
      <xsl:choose>
        <xsl:when test="$lang = 'en'">Availiability</xsl:when>
        <xsl:when test="$lang = 'sl'">Dostopnost</xsl:when>
      </xsl:choose>
    </A>
  </xsl:param>
  <xsl:param name="LABEL-idno">
    <A>
      <xsl:attribute name="href">
        <xsl:call-template name="teip4-elts">
          <xsl:with-param name="gi">idno</xsl:with-param>
        </xsl:call-template>
      </xsl:attribute>
      <xsl:choose>
        <xsl:when test="$lang = 'en'">Identifier number</xsl:when>
        <xsl:when test="$lang = 'sl'">Identifikacijska &#353;tevilka</xsl:when>
      </xsl:choose>
    </A>
  </xsl:param>
  <xsl:param name="LABEL-distributor">
    <A>
      <xsl:attribute name="href">
        <xsl:call-template name="teip4-elts">
          <xsl:with-param name="gi">distributor</xsl:with-param>
        </xsl:call-template>
      </xsl:attribute>
      <xsl:choose>
        <xsl:when test="$lang = 'en'">Distributor</xsl:when>
        <xsl:when test="$lang = 'sl'">Distributer</xsl:when>
      </xsl:choose>
    </A>
  </xsl:param>
  <xsl:param name="LABEL-publisher">
    <A>
      <xsl:attribute name="href">
        <xsl:call-template name="teip4-elts">
          <xsl:with-param name="gi">publisher</xsl:with-param>
        </xsl:call-template>
      </xsl:attribute>
      <xsl:choose>
        <xsl:when test="$lang = 'en'">Publisher</xsl:when>
        <xsl:when test="$lang = 'sl'">Izdajatelj</xsl:when>
      </xsl:choose>
    </A>
  </xsl:param>
  <xsl:param name="LABEL-title">
    <A>
      <xsl:attribute name="href">
        <xsl:call-template name="teip4-elts">
          <xsl:with-param name="gi">title</xsl:with-param>
        </xsl:call-template>
      </xsl:attribute>
      <xsl:choose>
        <xsl:when test="$lang = 'en'">Title</xsl:when>
        <xsl:when test="$lang = 'sl'">Naslov</xsl:when>
      </xsl:choose>
    </A>
  </xsl:param>
  <xsl:param name="LABEL-author">
    <A>
      <xsl:attribute name="href">
        <xsl:call-template name="teip4-elts">
          <xsl:with-param name="gi">author</xsl:with-param>
        </xsl:call-template>
      </xsl:attribute>
      <xsl:choose>
        <xsl:when test="$lang = 'en'">Author</xsl:when>
        <xsl:when test="$lang = 'sl'">Avtor</xsl:when>
      </xsl:choose>
    </A>
  </xsl:param>
  <xsl:param name="LABEL-date">
    <A>
      <xsl:attribute name="href">
        <xsl:call-template name="teip4-elts">
          <xsl:with-param name="gi">date</xsl:with-param>
        </xsl:call-template>
      </xsl:attribute>
      <xsl:choose>
        <xsl:when test="$lang = 'en'">Date</xsl:when>
        <xsl:when test="$lang = 'sl'">Datum</xsl:when>
      </xsl:choose>
    </A>
  </xsl:param>
</xsl:stylesheet>
